@@ -27,7 +27,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: bjm.c,v 1.15 2005/06/01 19:02:37 roland Exp $
+ *	$Id$
  */
 #include "defs.h"
 
@@ -123,8 +123,8 @@ struct tcb *tcp;
 			umove(tcp, tcp->u_arg[4], &ret);
 			tprintf(", %Zu", ret);
 		} else if ((tcp->u_arg[1]==QM_MODULES) ||
-			       	(tcp->u_arg[1]==QM_DEPS) ||
-			       	(tcp->u_arg[1]==QM_REFS)) {
+			   (tcp->u_arg[1]==QM_DEPS) ||
+			   (tcp->u_arg[1]==QM_REFS)) {
 			size_t	ret;
 
 			umove(tcp, tcp->u_arg[4], &ret);
@@ -142,7 +142,7 @@ struct tcb *tcp;
 					for (idx=0; idx<ret; idx++) {
 						if (idx!=0)
 							tprintf(",");
-						tprintf(mod);
+						tprintf("%s", mod);
 						mod+=strlen(mod)+1;
 					}
 					free(data);
@@ -197,8 +197,9 @@ sys_init_module(tcp)
 struct tcb *tcp;
 {
 	if (entering(tcp)) {
-		printpath(tcp, tcp->u_arg[0]);
-		tprintf(", %#lx", tcp->u_arg[1]);
+		tprintf("%#lx, ", tcp->u_arg[0]);
+		tprintf("%lu, ", tcp->u_arg[1]);
+		printstr(tcp, tcp->u_arg[2], -1);
 	}
 	return 0;
 }
