@@ -26,9 +26,17 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: defs.h,v 1.53 2004/10/06 22:27:43 roland Exp $
+ *	$Id$
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#ifdef MIPS
+#include <sgidefs.h>
+#endif
+
 #ifdef linux
 #include <features.h>
 #endif
@@ -40,14 +48,10 @@
 # endif
 #endif
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 /* configuration section */
 #ifndef MAX_QUALS
 #if defined(LINUX) && defined(MIPS)
-#define MAX_QUALS	5000	/* maximum number of syscalls, signals, etc. */
+#define MAX_QUALS	7000	/* maximum number of syscalls, signals, etc. */
 #else
 #define MAX_QUALS	2048	/* maximum number of syscalls, signals, etc. */
 #endif
@@ -60,7 +64,11 @@
 #define DEFAULT_ACOLUMN	40	/* default alignment column for results */
 #endif
 #ifndef MAX_ARGS
-#define MAX_ARGS	32	/* maximum number of args to a syscall */
+# ifdef HPPA
+#  define MAX_ARGS	6	/* maximum number of args to a syscall */
+# else
+#  define MAX_ARGS	32	/* maximum number of args to a syscall */
+# endif
 #endif
 #ifndef DEFAULT_SORTBY
 #define DEFAULT_SORTBY "time"	/* default sorting method for call profiling */
@@ -76,6 +84,10 @@
 #include <sys/time.h>
 #include <errno.h>
 
+#ifdef HAVE_STDBOOL_H
+#include <stdbool.h>
+#endif
+
 #ifdef STDC_HEADERS
 #include <stddef.h>
 #endif /* STDC_HEADERS */
@@ -88,12 +100,26 @@
 #  if defined(SPARC) || defined(SPARC64)
 #     define LINUXSPARC
 #  endif
-#  if defined(ALPHA)
-#     define LINUX_64BIT
-#  endif
 #  if defined(X86_64)
 #     define LINUX_X86_64
 #  endif
+#  if defined(MIPS) && _MIPS_SIM == _MIPS_SIM_ABI32
+#     define LINUX_MIPSO32
+#  endif
+#  if defined(MIPS) && _MIPS_SIM == _MIPS_SIM_NABI32
+#     define LINUX_MIPSN32
+#     define LINUX_MIPS64
+#  endif
+#  if defined(MIPS) && _MIPS_SIM == _MIPS_SIM_ABI64
+#     define LINUX_MIPSN64
+#     define LINUX_MIPS64
+#  endif
+#  if defined(ARM)
+#     define LINUX_ARM
+#  endif
+#  if defined(AVR32)
+#     define LINUX_AVR32
+#  endif
 #endif
 
 #if defined(SVR4) || defined(FREEBSD)
@@ -120,7 +146,7 @@
 #include <sys/pioctl.h>
 #endif /* FREEBSD */
 #else /* !USE_PROCFS */
-#if (defined(LINUXSPARC) || defined (LINUX_X86_64)) && defined(__GLIBC__)
+#if (defined(LINUXSPARC) || defined(LINUX_X86_64) || defined(LINUX_ARM) || defined(LINUX_AVR32)) && defined(__GLIBC__)
 #include <sys/ptrace.h>
 #else
 /* Work around awkward prototype in ptrace.h. */
@@ -192,12 +218,20 @@ extern int ptrace();
 #define DEFAULT_PERSONALITY 0
 
 #ifdef LINUXSPARC
-#include <linux/a.out.h>
-#include <asm/psr.h>
+/* Indexes into the pt_regs.u_reg[] array -- UREG_XX from kernel are all off
+ * by 1 and use Ix instead of Ox.  These work for both 32 and 64 bit Linux. */
+#define U_REG_G1 0
+#define U_REG_O0 7
+#define U_REG_O1 8
+#define PERSONALITY0_WORDSIZE 4
+#define PERSONALITY1_WORDSIZE 4
 #undef  SUPPORTED_PERSONALITIES
 #if defined(SPARC64)
+#include <asm/psrcompat.h>
 #define SUPPORTED_PERSONALITIES 3
+#define PERSONALITY2_WORDSIZE 8
 #else
+#include <asm/psr.h>
 #define SUPPORTED_PERSONALITIES 2
 #endif /* SPARC64 */
 #endif /* LINUXSPARC */
@@ -205,6 +239,15 @@ extern int ptrace();
 #ifdef X86_64
 #undef SUPPORTED_PERSONALITIES
 #define SUPPORTED_PERSONALITIES 2
+#define PERSONALITY0_WORDSIZE 8
+#define PERSONALITY1_WORDSIZE 4
+#endif
+
+#ifdef ARM
+#undef SUPPORTED_PERSONALITIES
+#define SUPPORTED_PERSONALITIES 2
+#define PERSONALITY0_WORDSIZE 4
+#define PERSONALITY1_WORDSIZE 4
 #endif
 
 #ifdef SVR4
@@ -269,6 +312,9 @@ struct tcb {
 	long scno;		/* System call number */
 	int u_nargs;		/* System call arguments */
 	long u_arg[MAX_ARGS];	/* System call arguments */
+#if defined (LINUX_MIPSN32)
+	long long ext_arg[MAX_ARGS];	/* System call arguments */
+#endif
 	int u_error;		/* Error code */
 	long u_rval;		/* (first) return value */
 #ifdef HAVE_LONG_LONG
@@ -302,6 +348,7 @@ struct tcb {
 	prstatus_t status;	/* procfs status structure */
 #endif
 #endif
+	int ptrace_errno;
 #ifdef FREEBSD
 	struct procfs_status status;
 	int pfd_reg;
@@ -315,14 +362,20 @@ struct tcb {
 #define TCB_INSYSCALL	00004	/* A system call is in progress */
 #define TCB_ATTACHED	00010	/* Process is not our own child */
 #define TCB_EXITING	00020	/* As far as we know, this process is exiting */
-#define TCB_SUSPENDED	00040	/* Process has done a wait(4), that can
-				   not be allowed to complete just now */
+#define TCB_SUSPENDED	00040	/* Process can not be allowed to resume just now */
 #define TCB_BPTSET	00100	/* "Breakpoint" set after fork(2) */
 #define TCB_SIGTRAPPED	00200	/* Process wanted to block SIGTRAP */
 #define TCB_FOLLOWFORK	00400	/* Process should have forks followed */
 #define TCB_REPRINT	01000	/* We should reprint this syscall on exit */
 #ifdef LINUX
-# if defined(ALPHA) || defined(SPARC) || defined(SPARC64) || defined(POWERPC) || defined(IA64) || defined(HPPA) || defined(SH) || defined(SH64) || defined(S390) || defined(S390X) || defined(ARM)
+/* x86 does not need TCB_WAITEXECVE.
+ * It can detect execve's SIGTRAP by looking at eax/rax.
+ * See "stray syscall exit: eax = " message in syscall_fixup().
+ */
+# if defined(ALPHA) || defined(AVR32) || defined(SPARC) || defined(SPARC64) \
+  || defined(POWERPC) || defined(IA64) || defined(HPPA) \
+  || defined(SH) || defined(SH64) || defined(S390) || defined(S390X) \
+  || defined(ARM) || defined(MIPS) || defined(BFIN)
 #  define TCB_WAITEXECVE 02000	/* ignore SIGTRAP after exceve */
 # endif
 # define TCB_CLONE_DETACHED 04000 /* CLONE_DETACHED set in creating syscall */
@@ -335,6 +388,8 @@ struct tcb {
 #   define __NR_exit_group 405
 #  elif defined I386
 #   define __NR_exit_group 252
+#  elif defined X86_64
+#   define __NR_exit_group 231
 #  elif defined IA64
 #   define __NR_exit_group 1236
 #  elif defined POWERPC
@@ -343,6 +398,8 @@ struct tcb {
 #   define __NR_exit_group 248
 #  elif defined SPARC || defined SPARC64
 #   define __NR_exit_group 188
+#  elif defined M68K
+#   define __NR_exit_group 247
 #  endif /* ALPHA et al */
 # endif	/* !__NR_exit_group */
 #endif /* LINUX */
@@ -368,6 +425,11 @@ struct xlat {
 	char *str;
 };
 
+extern const struct xlat open_mode_flags[];
+extern const struct xlat addrfams[];
+extern const struct xlat struct_user_offsets[];
+extern const struct xlat open_access_modes[];
+
 /* Format of syscall return values */
 #define RVAL_DECIMAL	000	/* decimal format */
 #define RVAL_HEX	001	/* hex format */
@@ -395,13 +457,13 @@ struct xlat {
 #define TRACE_NETWORK	004	/* Trace network-related syscalls. */
 #define TRACE_PROCESS	010	/* Trace process-related syscalls. */
 #define TRACE_SIGNAL	020	/* Trace signal-related syscalls. */
+#define TRACE_DESC	040	/* Trace file descriptor-related syscalls. */
 
 extern struct tcb **tcbtab;
-extern int qual_flags[];
-extern int debug, followfork, followvfork;
-extern int rflag, tflag, dtime, cflag, xflag, qflag;
+extern int *qual_flags;
+extern int debug, followfork;
+extern int dtime, cflag, xflag, qflag;
 extern int acolumn;
-extern char *outfname;
 extern unsigned int nprocs, tcbtabsize;
 extern int max_strlen;
 extern struct tcb *tcp_last;
@@ -412,34 +474,45 @@ extern struct tcb *tcp_last;
 #define P(args) ()
 #endif
 
+enum bitness_t { BITNESS_CURRENT = 0, BITNESS_32 };
+
 extern int set_personality P((int personality));
-extern char *xlookup P((const struct xlat *, int));
-extern struct tcb *alloctcb P((int));
+extern const char *xlookup P((const struct xlat *, int));
+extern struct tcb *alloc_tcb P((int, int));
 extern struct tcb *pid2tcb P((int));
 extern void droptcb P((struct tcb *));
-extern int expand_tcbtab P((void));
+extern void expand_tcbtab P((void));
+
+#define alloctcb(pid)	alloc_tcb((pid), 1)
 
 extern void set_sortby P((char *));
 extern void set_overhead P((int));
 extern void qualify P((char *));
-extern void newoutf P((struct tcb *));
 extern int get_scno P((struct tcb *));
+extern long known_scno P((struct tcb *));
+extern long do_ptrace P((int request, struct tcb *tcp, void *addr, void *data));
+extern int ptrace_restart P((int request, struct tcb *tcp, int sig));
 extern int trace_syscall P((struct tcb *));
-extern void printxval P((const struct xlat *, int, char *));
+extern int count_syscall P((struct tcb *, struct timeval *));
+extern void printxval P((const struct xlat *, int, const char *));
 extern int printargs P((struct tcb *));
 extern int addflags P((const struct xlat *, int));
-extern int printflags P((const struct xlat *, int));
+extern int printflags P((const struct xlat *, int, const char *));
+extern const char *sprintflags P((const char *, const struct xlat *, int));
 extern int umoven P((struct tcb *, long, int, char *));
 extern int umovestr P((struct tcb *, long, int, char *));
-extern int upeek P((int, long, long *));
+extern int upeek P((struct tcb *, long, long *));
 extern void dumpiov P((struct tcb *, int, long));
 extern void dumpstr P((struct tcb *, long, int));
-extern void string_quote P((char *str));
 extern void printstr P((struct tcb *, long, int));
 extern void printnum P((struct tcb *, long, char *));
+extern void printnum_int P((struct tcb *, long, char *));
 extern void printpath P((struct tcb *, long));
 extern void printpathn P((struct tcb *, long, int));
-extern void printtv P((struct tcb *, long));
+extern void printtv_bitness P((struct tcb *, long, enum bitness_t, int));
+extern void sprinttv P((struct tcb *, long, enum bitness_t, char *));
+extern void print_timespec P((struct tcb *, long));
+extern void sprint_timespec P((char *, struct tcb *, long));
 #ifdef HAVE_SIGINFO_T
 extern void printsiginfo P((siginfo_t *, int));
 #endif
@@ -452,15 +525,18 @@ extern int setbpt P((struct tcb *));
 extern int sigishandled P((struct tcb *, int));
 extern void printcall P((struct tcb *));
 extern const char *signame P((int));
+extern void print_sigset P((struct tcb *, long, int));
 extern void printsignal P((int));
 extern void printleader P((struct tcb *));
-extern void printtrailer P((struct tcb *));
+extern void printtrailer P((void));
 extern void tabto P((int));
 extern void call_summary P((FILE *));
-extern void fake_execve P((struct tcb *, char *, char *[], char *[]));
-extern void printtv32 P((struct tcb*, long));
-extern void tprint_iov P((struct tcb *, int, long));
+extern void tprint_iov P((struct tcb *, unsigned long, unsigned long));
+extern void tprint_open_modes P((mode_t));
+extern const char *sprint_open_modes P((mode_t));
+extern int is_restart_error P((struct tcb *));
 
+extern int change_syscall P((struct tcb *, int));
 #ifdef LINUX
 extern int internal_clone P((struct tcb *));
 #endif
@@ -478,6 +554,7 @@ extern int proc_ioctl P((struct tcb *, int, int));
 extern int stream_ioctl P((struct tcb *, int, int));
 #ifdef LINUX
 extern int rtc_ioctl P((struct tcb *, long, long));
+extern int scsi_ioctl P((struct tcb *, long, long));
 #endif
 
 extern void tv_tv P((struct timeval *, int, int));
@@ -502,6 +579,11 @@ extern int proc_open P((struct tcb *tcp, int attaching));
 #define umove(pid, addr, objp)	\
 	umoven((pid), (addr), sizeof *(objp), (char *) (objp))
 
+#define printtv(tcp, addr)	\
+	printtv_bitness((tcp), (addr), BITNESS_CURRENT, 0)
+#define printtv_special(tcp, addr)	\
+	printtv_bitness((tcp), (addr), BITNESS_CURRENT, 1)
+
 #ifdef __STDC__
 #ifdef __GNUC__
 extern void tprintf(const char *fmt, ...)
@@ -521,12 +603,14 @@ const char *strsignal P((int));
 #endif
 
 extern int current_personality;
+extern const int personality_wordsize[];
 
 struct sysent {
 	int	nargs;
 	int	sys_flags;
 	int	(*sys_func)();
 	const char *sys_name;
+	long	native_scno;	/* Match against SYS_* constants.  */
 };
 
 extern const struct sysent *sysent;
@@ -568,7 +652,7 @@ extern const int nsignals2;
 
 #if defined(FREEBSD) || (defined(LINUX) \
 			 && defined(POWERPC) && !defined(__powerpc64__)) \
-  || (defined (LINUX) && defined (MIPS) && !defined(__mips64))
+  || defined (LINUX_MIPSO32)
 /* ARRGH!  off_t args are aligned on 64 bit boundaries! */
 #define ALIGN64(tcp,arg)						\
 do {									\
