@@ -27,7 +27,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: desc.c,v 1.16 2004/10/20 02:18:50 roland Exp $
+ *	$Id$
  */
 
 #include "defs.h"
@@ -40,6 +40,9 @@
 #ifdef HAVE_SYS_EPOLL_H
 #include <sys/epoll.h>
 #endif
+#ifdef HAVE_LIBAIO_H
+#include <libaio.h>
+#endif
 
 #if HAVE_LONG_LONG_OFF_T
 /*
@@ -144,6 +147,18 @@ static const struct xlat fcntlcmds[] = {
 #endif
 #ifdef F_UNSHARE
 	{ F_UNSHARE,	"F_UNSHARE"	},
+#endif
+#ifdef F_SETLEASE
+	{ F_SETLEASE,	"F_SETLEASE"	},
+#endif
+#ifdef F_GETLEASE
+	{ F_GETLEASE,	"F_GETLEASE"	},
+#endif
+#ifdef F_NOTIFY
+	{ F_NOTIFY,	"F_NOTIFY"	},
+#endif
+#ifdef F_DUPFD_CLOEXEC
+	{ F_DUPFD_CLOEXEC,"F_DUPFD_CLOEXEC"},
 #endif
 	{ 0,		NULL		},
 };
@@ -180,6 +195,33 @@ static const struct xlat lockfcmds[] = {
 	{ 0,		NULL		},
 };
 
+#ifdef F_NOTIFY
+static const struct xlat notifyflags[] = {
+#ifdef DN_ACCESS
+	{ DN_ACCESS,	"DN_ACCESS"	},
+#endif
+#ifdef DN_MODIFY
+	{ DN_MODIFY,	"DN_MODIFY"	},
+#endif
+#ifdef DN_CREATE
+	{ DN_CREATE,	"DN_CREATE"	},
+#endif
+#ifdef DN_DELETE
+	{ DN_DELETE,	"DN_DELETE"	},
+#endif
+#ifdef DN_RENAME
+	{ DN_RENAME,	"DN_RENAME"	},
+#endif
+#ifdef DN_ATTRIB
+	{ DN_ATTRIB,	"DN_ATTRIB"	},
+#endif
+#ifdef DN_MULTISHOT
+	{ DN_MULTISHOT,	"DN_MULTISHOT"	},
+#endif
+	{ 0,		NULL		},
+};
+#endif
+
 static const struct xlat whence[] = {
 	{ SEEK_SET,	"SEEK_SET"	},
 	{ SEEK_CUR,	"SEEK_CUR"	},
@@ -190,16 +232,43 @@ static const struct xlat whence[] = {
 #ifndef HAVE_LONG_LONG_OFF_T
 /* fcntl/lockf */
 static void
-printflock(tcp, addr, getlk)
-struct tcb *tcp;
-long addr;
-int getlk;
+printflock(struct tcb *tcp, long addr, int getlk)
 {
 	struct flock fl;
 
-	if (umove(tcp, addr, &fl) < 0) {
-		tprintf("{...}");
-		return;
+#if SUPPORTED_PERSONALITIES > 1
+	if (personality_wordsize[current_personality] != sizeof(fl.l_start)) {
+		if (personality_wordsize[current_personality] == 4) {
+			/* 32-bit x86 app on x86_64 and similar cases */
+			struct {
+				short int l_type;
+				short int l_whence;
+				int32_t l_start; /* off_t */
+				int32_t l_len; /* off_t */
+				int32_t l_pid; /* pid_t */
+			} fl32;
+			if (umove(tcp, addr, &fl32) < 0) {
+				tprintf("{...}");
+				return;
+			}
+			fl.l_type = fl32.l_type;
+			fl.l_whence = fl32.l_whence;
+			fl.l_start = fl32.l_start;
+			fl.l_len = fl32.l_len;
+			fl.l_pid = fl32.l_pid;
+		} else {
+			/* let people know we have a problem here */
+			tprintf("{ <decode error: unsupported wordsize %d> }",
+				personality_wordsize[current_personality]);
+			return;
+		}
+	} else
+#endif
+	{
+		if (umove(tcp, addr, &fl) < 0) {
+			tprintf("{...}");
+			return;
+		}
 	}
 	tprintf("{type=");
 	printxval(lockfcmds, fl.l_type, "F_???");
@@ -216,10 +285,7 @@ int getlk;
 #if _LFS64_LARGEFILE || HAVE_LONG_LONG_OFF_T
 /* fcntl/lockf */
 static void
-printflock64(tcp, addr, getlk)
-struct tcb *tcp;
-long addr;
-int getlk;
+printflock64(struct tcb *tcp, long addr, int getlk)
 {
 	struct flock64 fl;
 
@@ -239,52 +305,26 @@ int getlk;
 }
 #endif
 
-static char *
-sprintflags(xlat, flags)
-const struct xlat *xlat;
-int flags;
-{
-	static char outstr[1024];
-	char *sep;
-
-	strcpy(outstr, "flags ");
-	sep = "";
-	for (; xlat->str; xlat++) {
-		if ((flags & xlat->val) == xlat->val) {
-			sprintf(outstr + strlen(outstr),
-				"%s%s", sep, xlat->str);
-			sep = "|";
-			flags &= ~xlat->val;
-		}
-	}
-	if (flags)
-		sprintf(outstr + strlen(outstr),
-			"%s%#x", sep, flags);
-	return outstr;
-}
-
 int
-sys_fcntl(tcp)
-struct tcb *tcp;
+sys_fcntl(struct tcb *tcp)
 {
-	extern const struct xlat openmodes[];
-
 	if (entering(tcp)) {
 		tprintf("%ld, ", tcp->u_arg[0]);
 		printxval(fcntlcmds, tcp->u_arg[1], "F_???");
 		switch (tcp->u_arg[1]) {
 		case F_SETFD:
 			tprintf(", ");
-			if (printflags(fdflags, tcp->u_arg[2]) == 0)
-				tprintf("0");
+			printflags(fdflags, tcp->u_arg[2], "FD_???");
 			break;
 		case F_SETOWN: case F_DUPFD:
+#ifdef F_DUPFD_CLOEXEC
+		case F_DUPFD_CLOEXEC:
+#endif
 			tprintf(", %ld", tcp->u_arg[2]);
 			break;
 		case F_SETFL:
 			tprintf(", ");
-			if (printflags(openmodes, tcp->u_arg[2] + 1) == 0)
-				tprintf("0");
+			tprint_open_modes(tcp->u_arg[2]);
 			break;
 		case F_SETLK: case F_SETLKW:
 #ifdef F_FREESP
@@ -299,32 +339,55 @@ struct tcb *tcp;
 #endif
 		/* Linux glibc defines SETLK64 as SETLK,
 		   even though the kernel has different values - as does Solaris. */
-#if defined(F_SETLK64) && F_SETLK64+0!=F_SETLK
+#if defined(F_SETLK64) && F_SETLK64 + 0 != F_SETLK
 		case F_SETLK64:
 #endif
-#if defined(F_SETLKW64) && F_SETLKW64+0!=F_SETLKW
+#if defined(F_SETLKW64) && F_SETLKW64 + 0 != F_SETLKW
 		case F_SETLKW64:
 #endif
 			tprintf(", ");
 			printflock64(tcp, tcp->u_arg[2], 0);
 			break;
 #endif
- 		}
+#ifdef F_NOTIFY
+		case F_NOTIFY:
+			tprintf(", ");
+			printflags(notifyflags, tcp->u_arg[2], "DN_???");
+			break;
+#endif
+#ifdef F_SETLEASE
+		case F_SETLEASE:
+			tprintf(", ");
+			printxval(lockfcmds, tcp->u_arg[2], "F_???");
+			break;
+#endif
+		}
 	}
 	else {
 		switch (tcp->u_arg[1]) {
 		case F_DUPFD:
+#ifdef F_DUPFD_CLOEXEC
+		case F_DUPFD_CLOEXEC:
+#endif
 		case F_SETFD: case F_SETFL:
 		case F_SETLK: case F_SETLKW:
 		case F_SETOWN: case F_GETOWN:
+#ifdef F_NOTIFY
+		case F_NOTIFY:
+#endif
+#ifdef F_SETLEASE
+		case F_SETLEASE:
+#endif
 			break;
 		case F_GETFD:
-			if (tcp->u_rval == 0)
+			if (syserror(tcp) || tcp->u_rval == 0)
 				return 0;
-			tcp->auxstr = sprintflags(fdflags, tcp->u_rval);
+			tcp->auxstr = sprintflags("flags ", fdflags, tcp->u_rval);
 			return RVAL_HEX|RVAL_STR;
 		case F_GETFL:
-			tcp->auxstr = sprintflags(openmodes, tcp->u_rval + 1);
+			if (syserror(tcp))
+				return 0;
+			tcp->auxstr = sprint_open_modes(tcp->u_rval);
 			return RVAL_HEX|RVAL_STR;
 		case F_GETLK:
 			tprintf(", ");
@@ -338,7 +401,14 @@ struct tcb *tcp;
 			printflock64(tcp, tcp->u_arg[2], 1);
 			break;
 #endif
- 		default:
+#ifdef F_GETLEASE
+		case F_GETLEASE:
+			if (syserror(tcp))
+				return 0;
+			tcp->auxstr = xlookup(lockfcmds, tcp->u_rval);
+			return RVAL_HEX|RVAL_STR;
+#endif
+		default:
 			tprintf(", %#lx", tcp->u_arg[2]);
 			break;
 		}
@@ -349,21 +419,18 @@ struct tcb *tcp;
 #ifdef LOCK_SH
 
 int
-sys_flock(tcp)
-struct tcb *tcp;
+sys_flock(struct tcb *tcp)
 {
 	if (entering(tcp)) {
 		tprintf("%ld, ", tcp->u_arg[0]);
-		if (!printflags(flockcmds, tcp->u_arg[1]))
-			tprintf("LOCK_???");
+		printflags(flockcmds, tcp->u_arg[1], "LOCK_???");
 	}
 	return 0;
 }
 #endif /* LOCK_SH */
 
 int
-sys_close(tcp)
-struct tcb *tcp;
+sys_close(struct tcb *tcp)
 {
 	if (entering(tcp)) {
 		tprintf("%ld", tcp->u_arg[0]);
@@ -372,8 +439,7 @@ struct tcb *tcp;
 }
 
 int
-sys_dup(tcp)
-struct tcb *tcp;
+sys_dup(struct tcb *tcp)
 {
 	if (entering(tcp)) {
 		tprintf("%ld", tcp->u_arg[0]);
@@ -381,43 +447,56 @@ struct tcb *tcp;
 	return 0;
 }
 
-int
-sys_dup2(tcp)
-struct tcb *tcp;
-{
-	if (entering(tcp)) {
-		tprintf("%ld, %ld", tcp->u_arg[0], tcp->u_arg[1]);
-	}
-	return 0;
-}
-
-int
-sys_getdtablesize(tcp)
-struct tcb *tcp;
-{
-	return 0;
-}
-
 static int
-decode_select(tcp, args, bitness)
-struct tcb *tcp;
-long *args;
-int bitness;
+do_dup2(struct tcb *tcp, int flags_arg)
+{
+	if (entering(tcp)) {
+		tprintf("%ld, %ld", tcp->u_arg[0], tcp->u_arg[1]);
+		if (flags_arg >= 0) {
+			tprintf(", ");
+			printflags(open_mode_flags, tcp->u_arg[flags_arg], "O_???");
+		}
+	}
+	return 0;
+}
+
+int
+sys_dup2(struct tcb *tcp)
+{
+	return do_dup2(tcp, -1);
+}
+
+#ifdef LINUX
+int
+sys_dup3(struct tcb *tcp)
+{
+	return do_dup2(tcp, 2);
+}
+#endif
+
+#if defined(ALPHA) || defined(FREEBSD) || defined(SUNOS4)
+int
+sys_getdtablesize(struct tcb *tcp)
+{
+	return 0;
+}
+#endif /* ALPHA || FREEBSD || SUNOS4 */
+
+static int
+decode_select(struct tcb *tcp, long *args, enum bitness_t bitness)
 {
 	int i, j, nfds;
-	fd_set fds;
-	struct timeval tv;
-#ifdef ALPHA
-	struct timeval32 {
-		unsigned tv_sec;
-		unsigned tv_usec;
-	} *tv32;
-#endif
+	unsigned int fdsize = ((((args[0] + 7) / 8) + sizeof(long) - 1)
+			       & -sizeof(long));
+	fd_set *fds;
 	static char outstr[1024];
 	char *sep;
 	long arg;
 
 	if (entering(tcp)) {
+		fds = (fd_set *) malloc(fdsize);
+		if (fds == NULL)
+			fprintf(stderr, "out of memory\n");
 		nfds = args[0];
 		tprintf("%d", nfds);
 		for (i = 0; i < 3; i++) {
@@ -426,39 +505,26 @@ int bitness;
 				tprintf(", NULL");
 				continue;
 			}
-			if (!verbose(tcp)) {
+			if (fds == NULL || !verbose(tcp)) {
 				tprintf(", %#lx", arg);
 				continue;
 			}
-			if (umove(tcp, arg, &fds) < 0) {
+			if (umoven(tcp, arg, fdsize, (char *) fds) < 0) {
 				tprintf(", [?]");
 				continue;
 			}
 			tprintf(", [");
 			for (j = 0, sep = ""; j < nfds; j++) {
-				if (FD_ISSET(j, &fds)) {
+				if (FD_ISSET(j, fds)) {
 					tprintf("%s%u", sep, j);
 					sep = " ";
 				}
 			}
 			tprintf("]");
 		}
-		if (!args[4])
-			tprintf(", NULL");
-		else if (!verbose(tcp))
-			tprintf(", %#lx", args[4]);
-		else if (umove(tcp, args[4], &tv) < 0)
-			tprintf(", {...}");
-		else {
-#ifdef ALPHA
-			if (bitness) {
-				tv32=(struct timeval32*)&tv;
-				tprintf(", {%u, %u}", tv32->tv_sec, tv32->tv_usec);
-			} else
-#endif
-				tprintf(", {%lu, %lu}",
-					(long) tv.tv_sec, (long) tv.tv_usec);
-		}
+		free(fds);
+		tprintf(", ");
+		printtv_bitness(tcp, args[4], bitness, 0);
 	}
 	else
 	{
@@ -472,6 +538,11 @@ int bitness;
 			tcp->auxstr = "Timeout";
 			return RVAL_STR;
 		}
+
+		fds = (fd_set *) malloc(fdsize);
+		if (fds == NULL)
+			fprintf(stderr, "out of memory\n");
+
 		outstr[0] = '\0';
 		for (i = 0; i < 3; i++) {
 			int first = 1;
@@ -479,10 +550,11 @@ int bitness;
 
 			tcp->auxstr = outstr;
 			arg = args[i+1];
-			if (!arg || umove(tcp, arg, &fds) < 0)
+			if (fds == NULL || !arg ||
+			    umoven(tcp, arg, fdsize, (char *) fds) < 0)
 				continue;
 			for (j = 0; j < args[0]; j++) {
-				if (FD_ISSET(j, &fds)) {
+				if (FD_ISSET(j, fds)) {
 					if (first) {
 						sprintf(str, "%s%s [%u", sep,
 							i == 0 ? "in" :
@@ -504,25 +576,16 @@ int bitness;
 			if (nfds == 0)
 				break;
 		}
+		free(fds);
 #ifdef LINUX
 		/* This contains no useful information on SunOS.  */
 		if (args[4]) {
-			char str[20];
+			char str[128];
 
-			if (umove(tcp, args[4], &tv) >= 0) {
-#ifdef ALPHA
-				if (bitness) {
-					tv32=(struct timeval32*)&tv;
-					sprintf(str, "%sleft {%u, %u}", sep,
-						tv32->tv_sec, tv32->tv_usec);
-				} else
-#endif
-					sprintf(str, "%sleft {%lu, %lu}", sep,
-						(long) tv.tv_sec, (long) tv.tv_usec);
-
-				if ((cumlen += strlen(str)) < sizeof(outstr))
-					strcat(outstr, str);
-			}
+			sprintf(str, "%sleft ", sep);
+			sprinttv(tcp, args[4], bitness, str + strlen(str));
+			if ((cumlen += strlen(str)) < sizeof(outstr))
+				strcat(outstr, str);
 		}
 #endif /* LINUX */
 		return RVAL_STR;
@@ -533,8 +596,7 @@ int bitness;
 #ifdef LINUX
 
 int
-sys_oldselect(tcp)
-struct tcb *tcp;
+sys_oldselect(struct tcb *tcp)
 {
 	long args[5];
 
@@ -542,20 +604,19 @@ struct tcb *tcp;
 		tprintf("[...]");
 		return 0;
 	}
-	return decode_select(tcp, args, 0);
+	return decode_select(tcp, args, BITNESS_CURRENT);
 }
 
 #ifdef ALPHA
 int
-sys_osf_select(tcp)
-struct tcb *tcp;
+sys_osf_select(struct tcb *tcp)
 {
 	long *args = tcp->u_arg;
-	return decode_select(tcp, args, 1);
+	return decode_select(tcp, args, BITNESS_32);
 }
 #endif
 
-static struct xlat epollctls[] = {
+static const struct xlat epollctls[] = {
 #ifdef EPOLL_CTL_ADD
 	{ EPOLL_CTL_ADD,	"EPOLL_CTL_ADD"	},
 #endif
@@ -568,7 +629,7 @@ static struct xlat epollctls[] = {
 	{ 0,			NULL		}
 };
 
-static struct xlat epollevents[] = {
+static const struct xlat epollevents[] = {
 #ifdef EPOLLIN
 	{ EPOLLIN,	"EPOLLIN"	},
 #endif
@@ -609,22 +670,27 @@ static struct xlat epollevents[] = {
 };
 
 int
-sys_epoll_create(tcp)
-struct tcb *tcp;
+sys_epoll_create(struct tcb *tcp)
 {
 	if (entering(tcp))
 		tprintf("%ld", tcp->u_arg[0]);
 	return 0;
 }
 
+int
+sys_epoll_create1(struct tcb *tcp)
+{
+	if (entering(tcp))
+		printflags(open_mode_flags, tcp->u_arg[0], "O_???");
+	return 0;
+}
+
 #ifdef HAVE_SYS_EPOLL_H
 static void
-print_epoll_event(ev)
-struct epoll_event *ev;
+print_epoll_event(struct epoll_event *ev)
 {
 	tprintf("{");
-	if (printflags(epollevents, ev->events) == 0)
-		tprintf("0");
+	printflags(epollevents, ev->events, "EPOLL???");
 	/* We cannot know what format the program uses, so print u32 and u64
 	   which will cover every value.  */
 	tprintf(", {u32=%" PRIu32 ", u64=%" PRIu64 "}}",
@@ -633,12 +699,11 @@ struct epoll_event *ev;
 #endif
 
 int
-sys_epoll_ctl(tcp)
-struct tcb *tcp;
+sys_epoll_ctl(struct tcb *tcp)
 {
 	if (entering(tcp)) {
 		tprintf("%ld, ", tcp->u_arg[0]);
-                printxval(epollctls, tcp->u_arg[1], "EPOLL_CTL_???");
+		printxval(epollctls, tcp->u_arg[1], "EPOLL_CTL_???");
 		tprintf(", %ld, ", tcp->u_arg[2]);
 		if (tcp->u_arg[3] == 0)
 			tprintf("NULL");
@@ -655,9 +720,8 @@ struct tcb *tcp;
 	return 0;
 }
 
-int
-sys_epoll_wait(tcp)
-struct tcb *tcp;
+static void
+epoll_wait_common(struct tcb *tcp)
 {
 	if (entering(tcp))
 		tprintf("%ld, ", tcp->u_arg[0]);
@@ -668,31 +732,247 @@ struct tcb *tcp;
 			tprintf("{}");
 		else {
 #ifdef HAVE_SYS_EPOLL_H
-			struct epoll_event evs[tcp->u_rval];
-			if (umove(tcp, tcp->u_arg[1], evs) == 0) {
-				unsigned long i;
-				tprintf("{");
-				for (i = 0; i < tcp->u_rval; ++i) {
-					if (i > 0)
-						tprintf(", ");
-					print_epoll_event(&evs[i]);
+			struct epoll_event ev, *start, *cur, *end;
+			int failed = 0;
+
+			tprintf("{");
+			start = (struct epoll_event *) tcp->u_arg[1];
+			end = start + tcp->u_rval;
+			for (cur = start; cur < end; ++cur) {
+				if (cur > start)
+					tprintf(", ");
+				if (umove(tcp, (long) cur, &ev) == 0)
+					print_epoll_event(&ev);
+				else {
+					tprintf("?");
+					failed = 1;
+					break;
 				}
-				tprintf("}");
 			}
+			tprintf("}");
+			if (failed)
+				tprintf(" %#lx", (long) start);
+#else
+			tprintf("{...}");
+#endif
+		}
+		tprintf(", %ld, %ld", tcp->u_arg[2], tcp->u_arg[3]);
+	}
+}
+
+int
+sys_epoll_wait(struct tcb *tcp)
+{
+	epoll_wait_common(tcp);
+	return 0;
+}
+
+int
+sys_epoll_pwait(struct tcb *tcp)
+{
+	epoll_wait_common(tcp);
+	if (exiting(tcp))
+		print_sigset(tcp, tcp->u_arg[4], 0);
+	return 0;
+}
+
+int
+sys_io_setup(struct tcb *tcp)
+{
+	if (entering(tcp))
+		tprintf("%ld, ", tcp->u_arg[0]);
+	else {
+		if (syserror(tcp))
+			tprintf("0x%0lx", tcp->u_arg[1]);
+		else {
+			unsigned long user_id;
+			if (umove(tcp, tcp->u_arg[1], &user_id) == 0)
+				tprintf("{%lu}", user_id);
+			else
+				tprintf("{...}");
+		}
+	}
+	return 0;
+}
+
+int
+sys_io_destroy(struct tcb *tcp)
+{
+	if (entering(tcp))
+		tprintf("%lu", tcp->u_arg[0]);
+	return 0;
+}
+
+int
+sys_io_submit(struct tcb *tcp)
+{
+	long nr;
+	if (entering(tcp)) {
+		tprintf("%lu, %ld, ", tcp->u_arg[0], tcp->u_arg[1]);
+		nr = tcp->u_arg[1];
+		/* and if nr is negative? */
+		if (nr == 0)
+			tprintf("{}");
+		else {
+#ifdef HAVE_LIBAIO_H
+			long i;
+			struct iocb *iocbp, **iocbs = (void *)tcp->u_arg[2];
+
+			for (i = 0; i < nr; i++, iocbs++) {
+				struct iocb iocb;
+				if (i == 0)
+					tprintf("{");
+				else
+					tprintf(", ");
+
+				if (umove(tcp, (unsigned long)iocbs, &iocbp) ||
+				    umove(tcp, (unsigned long)iocbp, &iocb)) {
+					tprintf("{...}");
+					continue;
+				}
+				tprintf("{%p, %u, %hu, %hu, %d}",
+					iocb.data, iocb.key,
+					iocb.aio_lio_opcode,
+					iocb.aio_reqprio, iocb.aio_fildes);
+			}
+			if (i)
+				tprintf("}");
+#else
+			tprintf("{...}");
+#endif
+		}
+	}
+	return 0;
+}
+
+int
+sys_io_cancel(struct tcb *tcp)
+{
+	if (entering(tcp)) {
+#ifdef HAVE_LIBAIO_H
+		struct iocb iocb;
+#endif
+		tprintf("%lu, ", tcp->u_arg[0]);
+#ifdef HAVE_LIBAIO_H
+		if (umove(tcp, tcp->u_arg[1], &iocb) == 0) {
+			tprintf("{%p, %u, %hu, %hu, %d}, ",
+				iocb.data, iocb.key,
+				iocb.aio_lio_opcode,
+				iocb.aio_reqprio, iocb.aio_fildes);
+		} else
+#endif
+			tprintf("{...}, ");
+	} else {
+		if (tcp->u_rval < 0)
+			tprintf("{...}");
+		else {
+#ifdef HAVE_LIBAIO_H
+			struct io_event event;
+			if (umove(tcp, tcp->u_arg[2], &event) == 0)
+				tprintf("{%p, %p, %ld, %ld}",
+					event.data, event.obj,
+					event.res, event.res2);
 			else
 #endif
 				tprintf("{...}");
 		}
-		tprintf(", %ld, %ld", tcp->u_arg[2], tcp->u_arg[3]);
+	}
+	return 0;
+}
+
+int
+sys_io_getevents(struct tcb *tcp)
+{
+	if (entering(tcp)) {
+		tprintf("%ld, %ld, %ld, ", tcp->u_arg[0], tcp->u_arg[1],
+			tcp->u_arg[2]);
+	} else {
+		if (tcp->u_rval == 0) {
+			tprintf("{}");
+		} else  {
+#ifdef HAVE_LIBAIO_H
+			struct io_event *events = (void *)tcp->u_arg[3];
+			long i, nr = tcp->u_rval;
+
+			for (i = 0; i < nr; i++, events++) {
+				struct io_event event;
+
+				if (i == 0)
+					tprintf("{");
+				else
+					tprintf(", ");
+
+				if (umove(tcp, (unsigned long)events, &event) != 0) {
+					tprintf("{...}");
+					continue;
+				}
+				tprintf("{%p, %p, %ld, %ld}", event.data,
+					event.obj, event.res, event.res2);
+			}
+			tprintf("}, ");
+#else
+				tprintf("{...}");
+#endif
+		}
+
+		print_timespec(tcp, tcp->u_arg[4]);
 	}
 	return 0;
 }
 #endif /* LINUX */
 
 int
-sys_select(tcp)
-struct tcb *tcp;
+sys_select(struct tcb *tcp)
 {
-	long *args = tcp->u_arg;
-	return decode_select(tcp, args, 0);
+	return decode_select(tcp, tcp->u_arg, BITNESS_CURRENT);
 }
+
+#ifdef LINUX
+int
+sys_pselect6(struct tcb *tcp)
+{
+	int rc = decode_select(tcp, tcp->u_arg, BITNESS_CURRENT);
+	if (entering(tcp)) {
+		struct {
+			void *ss;
+			unsigned long len;
+		} data;
+		if (umove(tcp, tcp->u_arg[5], &data) < 0)
+			tprintf(", %#lx", tcp->u_arg[5]);
+		else {
+			tprintf(", {");
+			if (data.len < sizeof(long))
+				tprintf("%#lx", (long)data.ss);
+			else
+				print_sigset(tcp, (long)data.ss, 0);
+			tprintf(", %lu}", data.len);
+		}
+	}
+	return rc;
+}
+
+static int
+do_eventfd(struct tcb *tcp, int flags_arg)
+{
+	if (entering(tcp)) {
+		tprintf("%lu", tcp->u_arg[0]);
+		if (flags_arg >= 0) {
+			tprintf(", ");
+			printflags(open_mode_flags, tcp->u_arg[flags_arg], "O_???");
+		}
+	}
+	return 0;
+}
+
+int
+sys_eventfd(struct tcb *tcp)
+{
+	return do_eventfd(tcp, -1);
+}
+
+int
+sys_eventfd2(struct tcb *tcp)
+{
+	return do_eventfd(tcp, 1);
+}
+#endif
