@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscallent.h,v 1.18 2006/01/12 22:34:50 roland Exp $
+ *	$Id$
  */
 
 	{ 6,	0,	printargs,		"osf_syscall"		}, /* 0, not implemented */
@@ -103,7 +103,7 @@
 	{ 5,	0,	printargs,		"osf_old_vadvise"	}, /* 72, not implemented */
 	{ 2,	0,	sys_munmap,		"munmap"		}, /* 73 */
 	{ 3,	0,	sys_mprotect,		"mprotect"		}, /* 74 */
-	{ 0,	0,	sys_madvise,		"madvise"		}, /* 75 */
+	{ 3,	0,	sys_madvise,		"madvise"		}, /* 75 */
 	{ 0,	0,	sys_vhangup,		"vhangup"		}, /* 76 */
 	{ 5,	0,	printargs,		"osf_kmodcall"		}, /* 77, not implemented */
 	{ 5,	0,	printargs,		"osf_mincore"		}, /* 78, not implemented */
@@ -336,7 +336,7 @@
 	{ 3,	TD,	sys_getdents,		"getdents"		}, /* 305 */
 	{ 2,	0,	sys_create_module,	"create_module"		}, /* 306 */
 	{ 4,	0,	sys_init_module,	"init_module"		}, /* 307 */
-	{ 1,	0,	sys_delete_module,	"delete_module"		}, /* 308 */
+	{ 2,	0,	sys_delete_module,	"delete_module"		}, /* 308 */
 	{ 1,	0,	sys_get_kernel_syms,	"get_kernel_syms"	}, /* 309 */
 	{ 3,	0,	sys_syslog,		"syslog"		}, /* 310 */
 	{ 3,	0,	sys_reboot,		"reboot"		}, /* 311 */
@@ -376,7 +376,7 @@
 	{ 5,	0,	printargs,		"pciconfig_read"	}, /* 345 */
 	{ 5,	0,	printargs,		"pciconfig_write"	}, /* 346 */
 	{ 5,	0,	sys_query_module,	"query_module"		}, /* 347 */
-	{ 5,	0,	printargs,		"prctl"			}, /* 348 */
+	{ 5,	0,	sys_prctl,		"prctl"			}, /* 348 */
 	{ 5,	TD,	sys_pread,		"pread"			}, /* 349 */
 	{ 5,	TD,	sys_pwrite,		"pwrite"		}, /* 350 */
 	{ 1,	TS,	printargs,		"rt_sigreturn"		}, /* 351 */
@@ -398,14 +398,14 @@
 	{ 2,	0,	sys_getcwd,		"getcwd"		}, /* 367 */
 	{ 2,	0,	sys_capget,		"capget"		}, /* 368 */
 	{ 2,	0,	sys_capset,		"capset"		}, /* 369 */
-	{ 4,	TD,	sys_sendfile,		"sendfile"		}, /* 370 */
-	{ 3,	0,	printargs,		"setresgid"		}, /* 371 */
-	{ 3,	0,	printargs,		"getresgid"		}, /* 372 */
+	{ 4,	TD|TN,	sys_sendfile,		"sendfile"		}, /* 370 */
+	{ 3,	0,	sys_setresgid,		"setresgid"		}, /* 371 */
+	{ 3,	0,	sys_getresgid,		"getresgid"		}, /* 372 */
 	{ 4,	0,	printargs,		"dipc"			}, /* 373, not implemented */
-	{ 2,	TF,	printargs,		"pivot_root"		}, /* 374 */
-	{ 3,	0,	printargs,		"mincore"		}, /* 375 */
-	{ 4,	0,	printargs,		"pciconfig_iobase"	}, /* 376 */
-	{ 4,	TD,	sys_getdents64,		"getdents64"		}, /* 377 */
+	{ 2,	TF,	sys_pivotroot,		"pivot_root"		}, /* 374 */
+	{ 3,	0,	sys_mincore,		"mincore"		}, /* 375 */
+	{ 3,	0,	printargs,		"pciconfig_iobase"	}, /* 376 */
+	{ 3,	TD,	sys_getdents64,		"getdents64"		}, /* 377 */
 	{ 0,	0,	printargs,		"gettid"		}, /* 378 */
 	{ 4,	TD,	sys_readahead,		"readahead"		}, /* 379 */
 	{ 5,	0,	printargs,		"SYS_380"		}, /* 380 */
@@ -422,7 +422,7 @@
 	{ 2,	TF,	sys_removexattr,	"removexattr"		}, /* 391 */
 	{ 2,	TF,	sys_removexattr,	"lremovexattr"		}, /* 392 */
 	{ 2,	TD,	sys_fremovexattr,	"fremovexattr"		}, /* 393 */
-	{ 5,	0,	sys_futex,		"futex"			}, /* 394 */
+	{ 6,	0,	sys_futex,		"futex"			}, /* 394 */
 	{ 3,	0,	sys_sched_setaffinity,	"sched_setaffinity"	}, /* 395 */
 	{ 3,	0,	sys_sched_getaffinity,	"sched_getaffinity"	}, /* 396 */
 	{ 5,	0,	printargs,		"tuxcall"		}, /* 397 */
@@ -467,3 +467,11 @@
 	{ 2,	0,	sys_mq_notify,		"mq_notify"		}, /* 436 */
 	{ 3,	0,	sys_mq_getsetattr,	"mq_getsetattr"		}, /* 437 */
 	{ 4,	0,	printargs,		"waitid"		}, /* 438 */
+	{ 5,	0,	printargs,		"add_key"		}, /* 439 */
+	{ 4,	0,	printargs,		"request_key"		}, /* 440 */
+	{ 5,	0,	printargs,		"keyctl"		}, /* 441 */
+	{ 3,	0,	printargs,		"ioprio_set"		}, /* 442 */
+	{ 2,	0,	printargs,		"ioprio_get"		}, /* 443 */
+	{ 0,	TD,	printargs,		"inotify_init"		}, /* 444 */
+	{ 3,	TD,	sys_inotify_add_watch,	"inotify_add_watch"	}, /* 445 */
+	{ 2,	TD,	sys_inotify_rm_watch,	"inotify_rm_watch"	}, /* 446 */
