@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscallent.h,v 1.22 2006/01/12 22:34:50 roland Exp $
+ *	$Id$
  */
 
 /*
@@ -245,108 +245,10 @@
 /* You must be careful to check ../syscallent.h so that this table
    starts where that one leaves off.
 */
+#if SYS_ipc_subcall + SYS_ipc_nsubcalls != 444
+# error fix me
+#endif
 
-	{ 8,	0,	printargs,		"SYS_343"	}, /* 343 */
-	{ 8,	0,	printargs,		"SYS_344"	}, /* 344 */
-	{ 8,	0,	printargs,		"SYS_345"	}, /* 345 */
-	{ 8,	0,	printargs,		"SYS_346"	}, /* 346 */
-	{ 8,	0,	printargs,		"SYS_347"	}, /* 347 */
-	{ 8,	0,	printargs,		"SYS_348"	}, /* 348 */
-	{ 8,	0,	printargs,		"SYS_349"	}, /* 349 */
-	{ 8,	0,	printargs,		"SYS_350"	}, /* 350 */
-	{ 8,	0,	printargs,		"SYS_351"	}, /* 351 */
-	{ 8,	0,	printargs,		"SYS_352"	}, /* 352 */
-	{ 8,	0,	printargs,		"SYS_353"	}, /* 353 */
-	{ 8,	0,	printargs,		"SYS_354"	}, /* 354 */
-	{ 8,	0,	printargs,		"SYS_355"	}, /* 355 */
-	{ 8,	0,	printargs,		"SYS_356"	}, /* 356 */
-	{ 8,	0,	printargs,		"SYS_357"	}, /* 357 */
-	{ 8,	0,	printargs,		"SYS_358"	}, /* 358 */
-	{ 8,	0,	printargs,		"SYS_359"	}, /* 359 */
-	{ 8,	0,	printargs,		"SYS_360"	}, /* 360 */
-	{ 8,	0,	printargs,		"SYS_361"	}, /* 361 */
-	{ 8,	0,	printargs,		"SYS_362"	}, /* 362 */
-	{ 8,	0,	printargs,		"SYS_363"	}, /* 363 */
-	{ 8,	0,	printargs,		"SYS_364"	}, /* 364 */
-	{ 8,	0,	printargs,		"SYS_365"	}, /* 365 */
-	{ 8,	0,	printargs,		"SYS_366"	}, /* 366 */
-	{ 8,	0,	printargs,		"SYS_367"	}, /* 367 */
-	{ 8,	0,	printargs,		"SYS_368"	}, /* 368 */
-	{ 8,	0,	printargs,		"SYS_369"	}, /* 369 */
-	{ 8,	0,	printargs,		"SYS_370"	}, /* 370 */
-	{ 8,	0,	printargs,		"SYS_371"	}, /* 371 */
-	{ 8,	0,	printargs,		"SYS_372"	}, /* 372 */
-	{ 8,	0,	printargs,		"SYS_373"	}, /* 373 */
-	{ 8,	0,	printargs,		"SYS_374"	}, /* 374 */
-	{ 8,	0,	printargs,		"SYS_375"	}, /* 375 */
-	{ 8,	0,	printargs,		"SYS_376"	}, /* 376 */
-	{ 8,	0,	printargs,		"SYS_377"	}, /* 377 */
-	{ 8,	0,	printargs,		"SYS_378"	}, /* 378 */
-	{ 8,	0,	printargs,		"SYS_379"	}, /* 379 */
-	{ 8,	0,	printargs,		"SYS_380"	}, /* 380 */
-	{ 8,	0,	printargs,		"SYS_381"	}, /* 381 */
-	{ 8,	0,	printargs,		"SYS_382"	}, /* 382 */
-	{ 8,	0,	printargs,		"SYS_383"	}, /* 383 */
-	{ 8,	0,	printargs,		"SYS_384"	}, /* 384 */
-	{ 8,	0,	printargs,		"SYS_385"	}, /* 385 */
-	{ 8,	0,	printargs,		"SYS_386"	}, /* 386 */
-	{ 8,	0,	printargs,		"SYS_387"	}, /* 387 */
-	{ 8,	0,	printargs,		"SYS_388"	}, /* 388 */
-	{ 8,	0,	printargs,		"SYS_389"	}, /* 389 */
-	{ 8,	0,	printargs,		"SYS_390"	}, /* 390 */
-	{ 8,	0,	printargs,		"SYS_391"	}, /* 391 */
-	{ 8,	0,	printargs,		"SYS_392"	}, /* 392 */
-	{ 8,	0,	printargs,		"SYS_393"	}, /* 393 */
-	{ 8,	0,	printargs,		"SYS_394"	}, /* 394 */
-	{ 8,	0,	printargs,		"SYS_395"	}, /* 395 */
-	{ 8,	0,	printargs,		"SYS_396"	}, /* 396 */
-	{ 8,	0,	printargs,		"SYS_397"	}, /* 397 */
-	{ 8,	0,	printargs,		"SYS_398"	}, /* 398 */
-	{ 8,	0,	printargs,		"SYS_399"	}, /* 399 */
-	{ 8,	0,	printargs,		"SYS_400"	}, /* 400 */
-	{ 8,	0,	printargs,		"SYS_401"	}, /* 401 */
-	{ 8,	0,	printargs,		"SYS_402"	}, /* 402 */
-	{ 8,	0,	printargs,		"SYS_403"	}, /* 403 */
-	{ 8,	0,	printargs,		"SYS_404"	}, /* 404 */
-	{ 8,	0,	printargs,		"SYS_405"	}, /* 405 */
-	{ 8,	0,	printargs,		"SYS_406"	}, /* 406 */
-	{ 8,	0,	printargs,		"SYS_407"	}, /* 407 */
-	{ 8,	0,	printargs,		"SYS_408"	}, /* 408 */
-	{ 8,	0,	printargs,		"SYS_409"	}, /* 409 */
-	{ 8,	0,	printargs,		"SYS_410"	}, /* 410 */
-	{ 8,	0,	printargs,		"SYS_411"	}, /* 411 */
-	{ 8,	0,	printargs,		"SYS_412"	}, /* 412 */
-	{ 8,	0,	printargs,		"SYS_413"	}, /* 413 */
-	{ 8,	0,	printargs,		"SYS_414"	}, /* 414 */
-	{ 8,	0,	printargs,		"SYS_415"	}, /* 415 */
-	{ 8,	0,	printargs,		"SYS_416"	}, /* 416 */
-	{ 8,	0,	printargs,		"SYS_417"	}, /* 417 */
-	{ 8,	0,	printargs,		"SYS_418"	}, /* 418 */
-	{ 8,	0,	printargs,		"SYS_419"	}, /* 419 */
-	{ 8,	0,	printargs,		"SYS_420"	}, /* 420 */
-	{ 8,	0,	printargs,		"SYS_421"	}, /* 421 */
-	{ 8,	0,	printargs,		"SYS_422"	}, /* 422 */
-	{ 8,	0,	printargs,		"SYS_423"	}, /* 423 */
-	{ 8,	0,	printargs,		"SYS_424"	}, /* 424 */
-	{ 8,	0,	printargs,		"SYS_425"	}, /* 425 */
-	{ 8,	0,	printargs,		"SYS_426"	}, /* 426 */
-	{ 8,	0,	printargs,		"SYS_427"	}, /* 427 */
-	{ 8,	0,	printargs,		"SYS_428"	}, /* 428 */
-	{ 8,	0,	printargs,		"SYS_429"	}, /* 429 */
-	{ 8,	0,	printargs,		"SYS_430"	}, /* 430 */
-	{ 8,	0,	printargs,		"SYS_431"	}, /* 431 */
-	{ 8,	0,	printargs,		"SYS_432"	}, /* 432 */
-	{ 8,	0,	printargs,		"SYS_433"	}, /* 433 */
-	{ 8,	0,	printargs,		"SYS_434"	}, /* 434 */
-	{ 8,	0,	printargs,		"SYS_435"	}, /* 435 */
-	{ 8,	0,	printargs,		"SYS_436"	}, /* 436 */
-	{ 8,	0,	printargs,		"SYS_437"	}, /* 437 */
-	{ 8,	0,	printargs,		"SYS_438"	}, /* 438 */
-	{ 8,	0,	printargs,		"SYS_439"	}, /* 439 */
-	{ 8,	0,	printargs,		"SYS_440"	}, /* 440 */
-	{ 8,	0,	printargs,		"SYS_441"	}, /* 441 */
-	{ 8,	0,	printargs,		"SYS_442"	}, /* 442 */
-	{ 8,	0,	printargs,		"SYS_443"	}, /* 443 */
 	{ 8,	0,	printargs,		"SYS_444"	}, /* 444 */
 	{ 8,	0,	printargs,		"SYS_445"	}, /* 445 */
 	{ 8,	0,	printargs,		"SYS_446"	}, /* 446 */
@@ -1037,7 +939,7 @@
 	{ 1,	0,	sys_adjtimex,		"adjtimex"	}, /* 1131 */
 	{ 2,	0,	sys_create_module,	"create_module"	}, /* 1132 */
 	{ 4,	0,	sys_init_module,	"init_module"	}, /* 1133 */
-	{ 1,	0,	sys_delete_module,	"delete_module"	}, /* 1134 */
+	{ 2,	0,	sys_delete_module,	"delete_module"	}, /* 1134 */
 	{ 1,	0,	sys_get_kernel_syms,	"get_kernel_syms"}, /* 1135 */
 	{ 5,	0,	sys_query_module,	"query_module"	}, /* 1136 */
 	{ 4,	0,	sys_quotactl,		"quotactl"	}, /* 1137 */
@@ -1090,7 +992,7 @@
 	{ 2,	TF,	sys_getcwd,		"getcwd"	}, /* 1184 */
 	{ 2,	0,	sys_capget,		"capget"	}, /* 1185 */
 	{ 2,	0,	sys_capset,		"capset"	}, /* 1186 */
-	{ 4,	TD,	sys_sendfile,		"sendfile"	}, /* 1187 */
+	{ 4,	TD|TN,	sys_sendfile,		"sendfile"	}, /* 1187 */
 	{ 5,	TN,	printargs,		"getpmsg"	}, /* 1188 */
 	{ 5,	TN,	printargs,		"putpmsg"	}, /* 1189 */
 	{ 3,	TN,	sys_socket,		"socket"	}, /* 1190 */
@@ -1111,13 +1013,13 @@
 	{ 3,	TN,	sys_sendmsg,		"sendmsg"	}, /* 1205 */
 	{ 3,	TN,	sys_recvmsg,		"recvmsg"	}, /* 1206 */
 	{ 2,	TF,	sys_pivotroot,		"pivot_root"	}, /* 1207 */
-	{ 3,	0,	printargs,		"mincore"	}, /* 1208 */
+	{ 3,	0,	sys_mincore,		"mincore"	}, /* 1208 */
 	{ 3,	0,	sys_madvise,		"madvise"	}, /* 1209 */
 	{ 2,	TF,	sys_stat,		"stat"		}, /* 1210 */
 	{ 2,	0,	sys_lstat,		"lstat"		}, /* 1211 */
 	{ 2,	TD,	sys_fstat,		"fstat"		}, /* 1212 */
 	{ 6,	TP,	sys_clone,		"clone2"	}, /* 1213 */
-	{ 3,	0,	printargs,		"getdents64"	}, /* 1214 */
+	{ 3,	TD,	sys_getdents64,		"getdents64"	}, /* 1214 */
 	{ 2,	0,	printargs,		"getunwind"	}, /* 1215 */
 	{ 4,	TD,	sys_readahead,		"readahead"	}, /* 1216 */
 	{ 5,	TF,	sys_setxattr,		"setxattr"	}, /* 1217 */
@@ -1133,7 +1035,7 @@
 	{ 2,	TF,	sys_removexattr,	"lremovexattr"	}, /* 1227 */
 	{ 2,	0,	sys_removexattr,	"fremovexattr"	}, /* 1228 */
 	{ 2,	TS,	sys_kill,		"tkill"		}, /* 1229 */
-	{ 5,	0,	sys_futex,		"futex"		}, /* 1230 */
+	{ 6,	0,	sys_futex,		"futex"		}, /* 1230 */
 	{ 3,	0,	sys_sched_setaffinity,	"sched_setaffinity"},/* 1231 */
 	{ 3,	0,	sys_sched_getaffinity,	"sched_getaffinity"},/* 1232 */
 	{ 1,	0,	printargs,		"set_tid_address"}, /* 1233 */
@@ -1174,38 +1076,42 @@
 	{ 5,	0,	printargs,		"sys_kexec_load" }, /* 1268 */
 	{ 5,	0,	printargs,		"vserver"	}, /* 1269 */
 	{ 5,	TP,	sys_waitid,		"waitid"	}, /* 1270 */
-	{ 8,	0,	printargs,		"SYS_1271"	}, /* 1271 */
-	{ 8,	0,	printargs,		"SYS_1272"	}, /* 1272 */
-	{ 8,	0,	printargs,		"SYS_1273"	}, /* 1273 */
-	{ 8,	0,	printargs,		"SYS_1274"	}, /* 1274 */
-	{ 8,	0,	printargs,		"SYS_1275"	}, /* 1275 */
-	{ 8,	0,	printargs,		"SYS_1276"	}, /* 1276 */
-	{ 8,	0,	printargs,		"SYS_1277"	}, /* 1277 */
-	{ 8,	0,	printargs,		"SYS_1278"	}, /* 1278 */
-	{ 8,	0,	printargs,		"SYS_1279"	}, /* 1279 */
-	{ 8,	0,	printargs,		"SYS_1280"	}, /* 1280 */
-	{ 8,	0,	printargs,		"SYS_1281"	}, /* 1281 */
-	{ 8,	0,	printargs,		"SYS_1282"	}, /* 1282 */
-	{ 8,	0,	printargs,		"SYS_1283"	}, /* 1283 */
-	{ 8,	0,	printargs,		"SYS_1284"	}, /* 1284 */
-	{ 8,	0,	printargs,		"SYS_1285"	}, /* 1285 */
-	{ 8,	0,	printargs,		"SYS_1286"	}, /* 1286 */
-	{ 8,	0,	printargs,		"SYS_1287"	}, /* 1287 */
-	{ 8,	0,	printargs,		"SYS_1288"	}, /* 1288 */
-	{ 8,	0,	printargs,		"SYS_1289"	}, /* 1289 */
-	{ 8,	0,	printargs,		"SYS_1290"	}, /* 1290 */
-	{ 8,	0,	printargs,		"SYS_1291"	}, /* 1291 */
-	{ 8,	0,	printargs,		"SYS_1292"	}, /* 1292 */
-	{ 8,	0,	printargs,		"SYS_1293"	}, /* 1293 */
-	{ 8,	0,	printargs,		"SYS_1294"	}, /* 1294 */
-	{ 8,	0,	printargs,		"SYS_1295"	}, /* 1295 */
-	{ 8,	0,	printargs,		"SYS_1296"	}, /* 1296 */
-	{ 8,	0,	printargs,		"SYS_1297"	}, /* 1297 */
-	{ 8,	0,	printargs,		"SYS_1298"	}, /* 1298 */
-	{ 8,	0,	printargs,		"SYS_1299"	}, /* 1299 */
-	{ 8,	0,	printargs,		"SYS_1300"	}, /* 1300 */
-	{ 8,	0,	printargs,		"SYS_1301"	}, /* 1301 */
-	{ 8,	0,	printargs,		"SYS_1302"	}, /* 1302 */
+	{ 5,	0,	printargs,		"add_key"	}, /* 1271 */
+	{ 4,	0,	printargs,		"request_key"	}, /* 1272 */
+	{ 5,	0,	printargs,		"keyctl"	}, /* 1273 */
+	{ 3,	0,	printargs,		"ioprio_set"	}, /* 1274 */
+	{ 2,	0,	printargs,		"ioprio_get"	}, /* 1275 */
+	{ 6,	0,	sys_move_pages,		"move_pages"	}, /* 1276 */
+	{ 0,	TD,	printargs,		"inotify_init"	}, /* 1277 */
+	{ 3,	TD,	sys_inotify_add_watch,	"inotify_add_watch" }, /* 1278 */
+	{ 2,	TD,	sys_inotify_rm_watch,	"inotify_rm_watch" }, /* 1279 */
+	{ 4,	0,	printargs,		"migrate_pages"	}, /* 1280 */
+	{ 4,	TD|TF,	sys_openat,		"openat"	}, /* 1281 */
+	{ 3,	TD|TF,	sys_mkdirat,		"mkdirat"	}, /* 1282 */
+	{ 4,	TD|TF,	sys_mknodat,		"mknodat"	}, /* 1283 */
+	{ 5,	TD|TF,	sys_fchownat,		"fchownat"	}, /* 1284 */
+	{ 3,	TD|TF,	sys_futimesat,		"futimesat"	}, /* 1285 */
+	{ 4,	TD|TD,	sys_newfstatat,		"newfstatat"	}, /* 1286 */
+	{ 3,	TD|TF,	sys_unlinkat,		"unlinkat"	}, /* 1287 */
+	{ 4,	TD|TF,	sys_renameat,		"renameat"	}, /* 1288 */
+	{ 5,	TD|TF,	sys_linkat,		"linkat"	}, /* 1289 */
+	{ 3,	TD|TF,	sys_symlinkat,		"symlinkat"	}, /* 1290 */
+	{ 4,	TD|TF,	sys_readlinkat,		"readlinkat"	}, /* 1291 */
+	{ 3,	TD|TF,	sys_fchmodat,		"fchmodat"	}, /* 1292 */
+	{ 3,	TD|TF,	sys_faccessat,		"faccessat"	}, /* 1293 */
+	{ 6,	TD,	sys_pselect6,		"pselect6"	}, /* 1294 */
+	{ 5,	TD,	sys_ppoll,		"ppoll"		}, /* 1295 */
+	{ 1,	TP,	sys_unshare,		"unshare"	}, /* 1296 */
+	{ 2,	0,	printargs,		"set_robust_list" }, /* 1297 */
+	{ 3,	0,	printargs,		"get_robust_list" }, /* 1298 */
+	{ 6,	TD,	printargs,		"splice"	}, /* 1299 */
+	{ 4,	TD,	printargs,		"sync_file_range" }, /* 1300 */
+	{ 4,	TD,	printargs,		"tee"		}, /* 1301 */
+	{ 4,	TD,	printargs,		"vmsplice"	}, /* 1302 */
 	{ 8,	0,	printargs,		"SYS_1303"	}, /* 1303 */
-	{ 8,	0,	printargs,		"SYS_1304"	}, /* 1304 */
-	{ 8,	0,	printargs,		"SYS_1305"	}, /* 1305 */
+	{ 3,	0,	sys_getcpu,		"getcpu"	}, /* 1304 */
+	{ 5,	TD,	sys_epoll_pwait,	"epoll_pwait"	}, /* 1305 */
+	{ 8,	0,	printargs,		"SYS_1306"	}, /* 1306 */
+	{ 3,	TD|TS,	sys_signalfd,		"signalfd"	}, /* 1307 */
+	{ 4,	TD,	sys_timerfd,		"timerfd"	}, /* 1308 */
+	{ 1,	TD,	sys_eventfd,		"eventfd"	}, /* 1309 */
