@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscallent.h,v 1.5 2005/08/03 11:27:34 roland Exp $
+ *	$Id$
  */
 
 	{ 0,	0,	sys_setup,		"setup"		}, /* 0 */
@@ -157,7 +157,7 @@
 	{ 3,	TS,	sys_sigprocmask,	"sigprocmask"	}, /* 126 */
 	{ 2,	0,	sys_create_module,	"create_module"	}, /* 127 */
 	{ 3,	0,	sys_init_module,	"init_module"	}, /* 128 */
-	{ 1,	0,	sys_delete_module,	"delete_module"	}, /* 129 */
+	{ 2,	0,	sys_delete_module,	"delete_module"	}, /* 129 */
 	{ 1,	0,	sys_get_kernel_syms,	"get_kernel_syms"}, /* 130 */
 	{ 4,	0,	sys_quotactl,		"quotactl"	}, /* 131 */
 	{ 1,	0,	sys_getpgid,		"getpgid"	}, /* 132 */
@@ -200,7 +200,7 @@
 	{ 3,	0,	printargs,		"nfsservctl"	}, /* 169 */
 	{ 3,	0,	sys_setresgid,		"setresgid"	}, /* 170 */
 	{ 3,	0,	sys_getresgid,		"getresgid"	}, /* 171 */
-	{ 5,	0,	printargs,		"prctl"		}, /* 172 */
+	{ 5,	0,	sys_prctl,		"prctl"		}, /* 172 */
 	{ 1,	TS,	printargs,		"rt_sigreturn"	}, /* 173 */
 	{ 4,	TS,	sys_rt_sigaction,	"rt_sigaction"  }, /* 174 */
 	{ 4,	TS,	sys_rt_sigprocmask,	"rt_sigprocmask"}, /* 175 */
@@ -215,7 +215,7 @@
 	{ 2,	0,	sys_capget,		"capget"	}, /* 184 */
 	{ 2,	0,	sys_capset,		"capset"	}, /* 185 */
 	{ 2,	TS,	sys_sigaltstack,	"sigaltstack"	}, /* 186 */
-	{ 4,	TD,	sys_sendfile,		"sendfile"	}, /* 187 */
+	{ 4,	TD|TN,	sys_sendfile,		"sendfile"	}, /* 187 */
 	{ 5,	0,	printargs,		"SYS_188"	}, /* 188 */
 	{ 5,	0,	printargs,		"SYS_189"	}, /* 189 */
 	{ 0,	TP,	sys_vfork,		"vfork"		}, /* 190 */
@@ -276,74 +276,183 @@
 	{ 4,	TI,	sys_shmdt,		"shmdt"		}, /* 245 */
 	{ 4,	TI,	sys_shmget,		"shmget"	}, /* 246 */
 	{ 4,	TI,	sys_shmctl,		"shmctl"	}, /* 247 */
-	{ 5,	0,	printargs,		"SYS_248"	}, /* 248 */
-	{ 5,	0,	printargs,		"SYS_249"	}, /* 249 */
-	{ 5,	0,	printargs,		"SYS_250"	}, /* 250 */
-	{ 5,	0,	printargs,		"SYS_251"	}, /* 251 */
-	{ 5,	0,	printargs,		"SYS_252"	}, /* 252 */
-	{ 5,	0,	printargs,		"SYS_253"	}, /* 253 */
-	{ 5,	0,	printargs,		"SYS_254"	}, /* 254 */
-	{ 5,	0,	printargs,		"SYS_255"	}, /* 255 */
-	{ 5,	0,	printargs,		"SYS_256"	}, /* 256 */
-	{ 5,	0,	printargs,		"SYS_257"	}, /* 257 */
-	{ 5,	0,	printargs,		"SYS_258"	}, /* 258 */
-	{ 5,	0,	printargs,		"SYS_259"	}, /* 259 */
-	{ 5,	0,	printargs,		"SYS_260"	}, /* 260 */
-	{ 5,	0,	printargs,		"SYS_261"	}, /* 261 */
-	{ 5,	0,	printargs,		"SYS_262"	}, /* 262 */
-	{ 5,	0,	printargs,		"SYS_263"	}, /* 263 */
-	{ 5,	0,	printargs,		"SYS_264"	}, /* 264 */
-	{ 5,	0,	printargs,		"SYS_265"	}, /* 265 */
-	{ 5,	0,	printargs,		"SYS_266"	}, /* 266 */
-	{ 5,	0,	printargs,		"SYS_267"	}, /* 267 */
-	{ 5,	0,	printargs,		"SYS_268"	}, /* 268 */
-	{ 5,	0,	printargs,		"SYS_269"	}, /* 269 */
-	{ 5,	0,	printargs,		"SYS_270"	}, /* 270 */
+	{ 3,	TD,	sys_getdents64,		"getdents64"	}, /* 248 */
+	{ 3,	TD,	sys_fcntl,		"fcntl64"	}, /* 249 */
+	{ 4,	0,	printargs,		"SYS_250"	}, /* 250 */
+	{ 4,	0,	printargs,		"SYS_251"	}, /* 251 */
+	{ 4,	0,	printargs,		"gettid"	}, /* 252 */
+	{ 5,	TD,	sys_readahead,		"readahead"	}, /* 253 */
+	{ 5,	TF,	sys_setxattr,		"setxattr"	}, /* 254 */
+	{ 5,	TF,	sys_setxattr,		"lsetxattr"	}, /* 255 */
+	{ 5,	TD,	sys_fsetxattr,		"fsetxattr"	}, /* 256 */
+	{ 4,	TF,	sys_getxattr,		"getxattr"	}, /* 257 */
+	{ 4,	TF,	sys_getxattr,		"lgetxattr"	}, /* 258 */
+	{ 4,	0,	sys_fgetxattr,		"fgetxattr"	}, /* 259 */
+	{ 3,	TF,	sys_listxattr,		"listxattr"	}, /* 260 */
+	{ 3,	TF,	sys_listxattr,		"llistxattr"	}, /* 261 */
+	{ 3,	0,	sys_flistxattr,		"flistxattr"	}, /* 262 */
+	{ 2,	TF,	sys_removexattr,	"removexattr"	}, /* 263 */
+	{ 2,	TF,	sys_removexattr,	"lremovexattr"	}, /* 264 */
+	{ 2,	TD,	sys_fremovexattr,	"fremovexattr"	}, /* 265 */
+	{ 2,	TD,	sys_kill,		"tkill"		}, /* 266 */
+	{ 5,	TD|TN,	sys_sendfile64,		"sendfile64"	}, /* 267 */
+	{ 6,	0,	sys_futex,		"futex"		}, /* 268 */
+	{ 3,	0,	sys_sched_setaffinity,	"sched_setaffinity"}, /* 269 */
+	{ 3,	0,	sys_sched_getaffinity,	"sched_getaffinity"}, /* 270 */
 	{ 5,	0,	printargs,		"SYS_271"	}, /* 271 */
 	{ 5,	0,	printargs,		"SYS_272"	}, /* 272 */
-	{ 5,	0,	printargs,		"SYS_273"	}, /* 273 */
-	{ 5,	0,	printargs,		"SYS_274"	}, /* 274 */
-	{ 5,	0,	printargs,		"SYS_275"	}, /* 275 */
-	{ 5,	0,	printargs,		"SYS_276"	}, /* 276 */
-	{ 5,	0,	printargs,		"SYS_277"	}, /* 277 */
-	{ 5,	0,	printargs,		"SYS_278"	}, /* 278 */
+	{ 2,	0,	sys_io_setup,		"io_setup"	}, /* 273 */
+	{ 1,	0,	sys_io_destroy,		"io_destroy"	}, /* 274 */
+	{ 5,	0,	sys_io_getevents,	"io_getevents"	}, /* 275 */
+	{ 3,	0,	sys_io_submit,		"io_submit"	}, /* 276 */
+	{ 3,	0,	sys_io_cancel,		"io_cancel"	}, /* 277 */
+	{ 5,	0,	sys_fadvise64,		"fadvise64"	}, /* 278 */
 	{ 5,	0,	printargs,		"SYS_279"	}, /* 279 */
-	{ 5,	0,	printargs,		"SYS_280"	}, /* 280 */
-	{ 5,	0,	printargs,		"SYS_281"	}, /* 281 */
-	{ 5,	0,	printargs,		"SYS_282"	}, /* 282 */
-	{ 5,	0,	printargs,		"SYS_283"	}, /* 283 */
-	{ 5,	0,	printargs,		"SYS_284"	}, /* 284 */
-	{ 5,	0,	printargs,		"SYS_285"	}, /* 285 */
-	{ 5,	0,	printargs,		"SYS_286"	}, /* 286 */
-	{ 5,	0,	printargs,		"SYS_287"	}, /* 287 */
-	{ 5,	0,	printargs,		"SYS_288"	}, /* 288 */
-	{ 5,	0,	printargs,		"SYS_289"	}, /* 289 */
-	{ 5,	0,	printargs,		"SYS_290"	}, /* 290 */
-	{ 5,	0,	printargs,		"SYS_291"	}, /* 291 */
-	{ 5,	0,	printargs,		"SYS_292"	}, /* 292 */
-	{ 5,	0,	printargs,		"SYS_293"	}, /* 293 */
-	{ 5,	0,	printargs,		"SYS_294"	}, /* 294 */
-	{ 5,	0,	printargs,		"SYS_295"	}, /* 295 */
-	{ 5,	0,	printargs,		"SYS_296"	}, /* 296 */
-	{ 5,	0,	printargs,		"SYS_297"	}, /* 297 */
-	{ 5,	0,	printargs,		"SYS_298"	}, /* 298 */
-	{ 5,	0,	printargs,		"SYS_299"	}, /* 299 */
-	{ 8,	0,	printargs,		"socket_subcall"}, /* 300 */
-	{ 3,	TN,	sys_socket,		"socket"	}, /* 301 */
-	{ 3,	TN,	sys_bind,		"bind"		}, /* 302 */
-	{ 3,	TN,	sys_connect,		"connect"	}, /* 303 */
-	{ 2,	TN,	sys_listen,		"listen"	}, /* 304 */
-	{ 3,	TN,	sys_accept,		"accept"	}, /* 305 */
-	{ 3,	TN,	sys_getsockname,	"getsockname"	}, /* 306 */
-	{ 3,	TN,	sys_getpeername,	"getpeername"	}, /* 307 */
-	{ 4,	TN,	sys_socketpair,		"socketpair"	}, /* 308 */
-	{ 4,	TN,	sys_send,		"send"		}, /* 309 */
-	{ 4,	TN,	sys_recv,		"recv"		}, /* 310 */
-	{ 6,	TN,	sys_sendto,		"sendto"	}, /* 311 */
-	{ 6,	TN,	sys_recvfrom,		"recvfrom"	}, /* 312 */
-	{ 2,	TN,	sys_shutdown,		"shutdown"	}, /* 313 */
-	{ 5,	TN,	sys_setsockopt,		"setsockopt"	}, /* 314 */
-	{ 5,	TN,	sys_getsockopt,		"getsockopt"	}, /* 315 */
-	{ 5,	TN,	sys_sendmsg,		"sendmsg"	}, /* 316 */
-	{ 5,	TN,	sys_recvmsg,		"recvmsg"	}, /* 317 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 318 */
+	{ 1,	TP,	sys_exit,		"exit_group"	}, /* 280 */
+	{ 4,	0,	printargs,		"lookup_dcookie"}, /* 281 */
+	{ 1,	0,	sys_epoll_create,	"epoll_create"	}, /* 282 */
+	{ 4,	TD,	sys_epoll_ctl,		"epoll_ctl"	}, /* 283 */
+	{ 3,	TD,	sys_epoll_wait,		"epoll_wait"	}, /* 284 */
+	{ 5,	0,	sys_remap_file_pages,	"remap_file_pages"}, /* 285 */
+	{ 1,	0,	printargs,		"set_tid_address"}, /* 286 */
+	{ 3,	0,	sys_timer_create,	"timer_create"	}, /* 287 */
+	{ 4,	0,	sys_timer_settime,	"timer_settime"	}, /* 288 */
+	{ 2,	0,	sys_timer_gettime,	"timer_gettime"	}, /* 289 */
+	{ 1,	0,	sys_timer_getoverrun,	"timer_getoverrun"}, /* 290 */
+	{ 1,	0,	sys_timer_delete,	"timer_delete"	}, /* 291 */
+	{ 2,	0,	sys_clock_settime,	"clock_settime"	}, /* 292 */
+	{ 2,	0,	sys_clock_gettime,	"clock_gettime"	}, /* 293 */
+	{ 2,	0,	sys_clock_getres,	"clock_getres"	}, /* 294 */
+	{ 4,	0,	sys_clock_nanosleep,	"clock_nanosleep"}, /* 295 */
+	{ 3,	TF,	sys_statfs64,		"statfs64"	}, /* 296 */
+	{ 2,	TD,	sys_fstatfs64,		"fstatfs64"	}, /* 297 */
+	{ 3,	TS,	sys_tgkill,		"tgkill"	}, /* 298 */
+	{ 2,	TF,	sys_utimes,		"utimes"	}, /* 299 */
+	{ 6,	0,	sys_fadvise64_64,	"fadvise64_64"	}, /* 300 */
+	{ 0,	0,	printargs,		"SYS_301"	}, /* 301 */
+	{ 4,	0,	sys_mbind,		"mbind"		}, /* 302 */
+	{ 5,	0,	sys_get_mempolicy,	"get_mempolicy"	}, /* 303 */
+	{ 3,	0,	sys_set_mempolicy,	"set_mempolicy"	}, /* 304 */
+	{ 4,	0,	sys_mq_open,		"mq_open"	}, /* 305 */
+	{ 1,	0,	sys_mq_unlink,		"mq_unlink"	}, /* 306 */
+	{ 5,	0,	sys_mq_timedsend,	"mq_timedsend"	}, /* 307 */
+	{ 5,	0,	sys_mq_timedreceive,	"mq_timedreceive"}, /* 308 */
+	{ 2,	0,	sys_mq_notify,		"mq_notify"	}, /* 309 */
+	{ 3,	0,	sys_mq_getsetattr,	"mq_getsetattr"	}, /* 310 */
+	{ 5,	0,	printargs,		"kexec_load"	}, /* 311 */
+	{ 5,	TP,	sys_waitid,		"waitid"	}, /* 312 */
+	{ 5,	0,	printargs,		"add_key"	}, /* 313 */
+	{ 4,	0,	printargs,		"request_key"	}, /* 314 */
+	{ 5,	0,	printargs,		"keyctl"	}, /* 315 */
+	{ 3,	0,	printargs,		"ioprio_set"	}, /* 316 */
+	{ 2,	0,	printargs,		"ioprio_get"	}, /* 317 */
+	{ 0,	TD,	printargs,		"inotify_init"	}, /* 318 */
+	{ 3,	TD,	printargs,		"inotify_add_watch"}, /* 319 */
+	{ 2,	TD,	printargs,		"inotify_rm_watch"}, /* 320 */
+	{ 5,	0,	printargs,		"SYS_321"	}, /* 321 */
+	{ 4,	0,	printargs,		"migrate_pages"	}, /* 322 */
+	{ 4,	TD|TF,	sys_openat,		"openat"	}, /* 323 */
+	{ 3,	TD|TF,	sys_mkdirat,		"mkdirat"	}, /* 324 */
+	{ 4,	TD|TF,	sys_mknodat,		"mknodat"	}, /* 325 */
+	{ 5,	TD|TF,	sys_fchownat,		"fchownat"	}, /* 326 */
+	{ 3,	TD|TF,	sys_futimesat,		"futimesat"	}, /* 327 */
+	{ 4,	TD|TF,	sys_newfstatat,		"newfstatat"	}, /* 328 */
+	{ 3,	TD|TF,	sys_unlinkat,		"unlinkat"	}, /* 329 */
+	{ 4,	TD|TF,	sys_renameat,		"renameat"	}, /* 330 */
+	{ 5,	TD|TF,	sys_linkat,		"linkat"	}, /* 331 */
+	{ 3,	TD|TF,	sys_symlinkat,		"symlinkat"	}, /* 332 */
+	{ 4,	TD|TF,	sys_readlinkat,		"readlinkat"	}, /* 333 */
+	{ 3,	TD|TF,	sys_fchmodat,		"fchmodat"	}, /* 334 */
+	{ 3,	TD|TF,	sys_faccessat,		"faccessat"	}, /* 335 */
+	{ 6,	TD,	sys_pselect6,		"pselect6"	}, /* 336 */
+	{ 5,	TD,	sys_ppoll,		"ppoll"		}, /* 337 */
+	{ 1,	TP,	sys_unshare,		"unshare"	}, /* 338 */
+	{ 2,	0,	printargs,		"set_robust_list"}, /* 339 */
+	{ 3,	0,	printargs,		"get_robust_list"}, /* 340 */
+	{ 6,	TD,	printargs,		"splice"	}, /* 341 */
+	{ 4,	TD,	printargs,		"sync_file_range"}, /* 342 */
+	{ 4,	TD,	printargs,		"tee"		}, /* 343 */
+	{ 5,	TD,	printargs,		"vmsplice"	}, /* 344 */
+	{ 6,	0,	sys_move_pages,		"move_pages"	}, /* 345 */
+	{ 3,	0,	sys_getcpu,		"getcpu"	}, /* 346 */
+	{ 5,	TD,	sys_epoll_pwait,	"epoll_pwait"	}, /* 347 */
+	{ 4,	TD|TF,	sys_utimensat,		"utimensat"	}, /* 348 */
+	{ 3,	TD|TS,	sys_signalfd,		"signalfd"	}, /* 349 */
+	{ 4,	TD,	sys_timerfd,		"timerfd"	}, /* 350 */
+	{ 1,	TD,	sys_eventfd,		"eventfd"	}, /* 351 */
+	{ 6,	0,	printargs,		"fallocate"	}, /* 352 */
+	{ 5,	0,	printargs,		"SYS_353"	}, /* 353 */
+	{ 5,	0,	printargs,		"SYS_354"	}, /* 354 */
+	{ 5,	0,	printargs,		"SYS_355"	}, /* 355 */
+	{ 5,	0,	printargs,		"SYS_356"	}, /* 356 */
+	{ 5,	0,	printargs,		"SYS_357"	}, /* 357 */
+	{ 5,	0,	printargs,		"SYS_358"	}, /* 358 */
+	{ 5,	0,	printargs,		"SYS_359"	}, /* 359 */
+	{ 5,	0,	printargs,		"SYS_360"	}, /* 360 */
+	{ 5,	0,	printargs,		"SYS_361"	}, /* 361 */
+	{ 5,	0,	printargs,		"SYS_362"	}, /* 362 */
+	{ 5,	0,	printargs,		"SYS_363"	}, /* 363 */
+	{ 5,	0,	printargs,		"SYS_364"	}, /* 364 */
+	{ 5,	0,	printargs,		"SYS_365"	}, /* 365 */
+	{ 5,	0,	printargs,		"SYS_366"	}, /* 366 */
+	{ 5,	0,	printargs,		"SYS_367"	}, /* 367 */
+	{ 5,	0,	printargs,		"SYS_368"	}, /* 368 */
+	{ 5,	0,	printargs,		"SYS_369"	}, /* 369 */
+	{ 5,	0,	printargs,		"SYS_370"	}, /* 370 */
+	{ 5,	0,	printargs,		"SYS_371"	}, /* 371 */
+	{ 5,	0,	printargs,		"SYS_372"	}, /* 372 */
+	{ 5,	0,	printargs,		"SYS_373"	}, /* 373 */
+	{ 5,	0,	printargs,		"SYS_374"	}, /* 374 */
+	{ 5,	0,	printargs,		"SYS_375"	}, /* 375 */
+	{ 5,	0,	printargs,		"SYS_376"	}, /* 376 */
+	{ 5,	0,	printargs,		"SYS_377"	}, /* 377 */
+	{ 5,	0,	printargs,		"SYS_378"	}, /* 378 */
+	{ 5,	0,	printargs,		"SYS_379"	}, /* 379 */
+	{ 5,	0,	printargs,		"SYS_380"	}, /* 380 */
+	{ 5,	0,	printargs,		"SYS_381"	}, /* 381 */
+	{ 5,	0,	printargs,		"SYS_382"	}, /* 382 */
+	{ 5,	0,	printargs,		"SYS_383"	}, /* 383 */
+	{ 5,	0,	printargs,		"SYS_384"	}, /* 384 */
+	{ 5,	0,	printargs,		"SYS_385"	}, /* 385 */
+	{ 5,	0,	printargs,		"SYS_386"	}, /* 386 */
+	{ 5,	0,	printargs,		"SYS_387"	}, /* 387 */
+	{ 5,	0,	printargs,		"SYS_388"	}, /* 388 */
+	{ 5,	0,	printargs,		"SYS_389"	}, /* 389 */
+	{ 5,	0,	printargs,		"SYS_390"	}, /* 390 */
+	{ 5,	0,	printargs,		"SYS_391"	}, /* 391 */
+	{ 5,	0,	printargs,		"SYS_392"	}, /* 392 */
+	{ 5,	0,	printargs,		"SYS_393"	}, /* 393 */
+	{ 5,	0,	printargs,		"SYS_394"	}, /* 394 */
+	{ 5,	0,	printargs,		"SYS_395"	}, /* 395 */
+	{ 5,	0,	printargs,		"SYS_396"	}, /* 396 */
+	{ 5,	0,	printargs,		"SYS_397"	}, /* 397 */
+	{ 5,	0,	printargs,		"SYS_398"	}, /* 398 */
+	{ 5,	0,	printargs,		"SYS_399"	}, /* 399 */
+
+#if SYS_socket_subcall != 400
+ #error fix me
+#endif
+	{ 8,	0,	printargs,		"socket_subcall"}, /* 400 */
+	{ 3,	TN,	sys_socket,		"socket"	}, /* 401 */
+	{ 3,	TN,	sys_bind,		"bind"		}, /* 402 */
+	{ 3,	TN,	sys_connect,		"connect"	}, /* 403 */
+	{ 2,	TN,	sys_listen,		"listen"	}, /* 404 */
+	{ 3,	TN,	sys_accept,		"accept"	}, /* 405 */
+	{ 3,	TN,	sys_getsockname,	"getsockname"	}, /* 406 */
+	{ 3,	TN,	sys_getpeername,	"getpeername"	}, /* 407 */
+	{ 4,	TN,	sys_socketpair,		"socketpair"	}, /* 408 */
+	{ 4,	TN,	sys_send,		"send"		}, /* 409 */
+	{ 4,	TN,	sys_recv,		"recv"		}, /* 410 */
+	{ 6,	TN,	sys_sendto,		"sendto"	}, /* 411 */
+	{ 6,	TN,	sys_recvfrom,		"recvfrom"	}, /* 412 */
+	{ 2,	TN,	sys_shutdown,		"shutdown"	}, /* 413 */
+	{ 5,	TN,	sys_setsockopt,		"setsockopt"	}, /* 414 */
+	{ 5,	TN,	sys_getsockopt,		"getsockopt"	}, /* 415 */
+	{ 5,	TN,	sys_sendmsg,		"sendmsg"	}, /* 416 */
+	{ 5,	TN,	sys_recvmsg,		"recvmsg"	}, /* 417 */
+	{ 4,	TN,	sys_accept4,		"accept4"	}, /* 418 */
+
+#if SYS_ipc_subcall != 419
+ #error fix me
+#endif
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 419 */
