@@ -27,7 +27,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: net.c,v 1.51 2005/07/04 23:33:38 roland Exp $
+ *	$Id$
  */
 
 #include "defs.h"
@@ -320,17 +320,32 @@ static const struct xlat socktypes[] = {
 #ifdef SOCK_RAW
 	{ SOCK_RAW,	"SOCK_RAW"	},
 #endif
+#ifdef SOCK_RDM
+	{ SOCK_RDM,	"SOCK_RDM"	},
+#endif
 #ifdef SOCK_SEQPACKET
 	{ SOCK_SEQPACKET,"SOCK_SEQPACKET"},
 #endif
-#ifdef SOCK_RDM
-	{ SOCK_RDM,	"SOCK_RDM"	},
+#ifdef SOCK_DCCP
+	{ SOCK_DCCP,	"SOCK_DCCP"	},
 #endif
 #ifdef SOCK_PACKET
 	{ SOCK_PACKET,	"SOCK_PACKET"	},
 #endif
 	{ 0,		NULL		},
 };
+const struct xlat sock_type_flags[] = {
+#ifdef SOCK_CLOEXEC
+	{ SOCK_CLOEXEC,	"SOCK_CLOEXEC"	},
+#endif
+#ifdef SOCK_NONBLOCK
+	{ SOCK_NONBLOCK,"SOCK_NONBLOCK"	},
+#endif
+	{ 0,		NULL		},
+};
+#ifndef SOCK_TYPE_MASK
+# define SOCK_TYPE_MASK 0xf
+#endif
 static const struct xlat socketlayers[] = {
 #if defined(SOL_IP)
 	{ SOL_IP,	"SOL_IP"	},
@@ -437,59 +452,62 @@ static const struct xlat protocols[] = {
 	{ 0,		NULL		},
 };
 static const struct xlat msg_flags[] = {
-	{ MSG_OOB,	"MSG_OOB"	},
+	{ MSG_OOB,		"MSG_OOB"		},
 #ifdef MSG_DONTROUTE
-	{ MSG_DONTROUTE,"MSG_DONTROUTE"	},
+	{ MSG_DONTROUTE,	"MSG_DONTROUTE"		},
 #endif
 #ifdef MSG_PEEK
-	{ MSG_PEEK,	"MSG_PEEK"	},
+	{ MSG_PEEK,		"MSG_PEEK"		},
 #endif
 #ifdef MSG_CTRUNC
-	{ MSG_CTRUNC,	"MSG_CTRUNC"	},
+	{ MSG_CTRUNC,		"MSG_CTRUNC"		},
 #endif
 #ifdef MSG_PROXY
-	{ MSG_PROXY,	"MSG_PROXY"	},
+	{ MSG_PROXY,		"MSG_PROXY"		},
 #endif
 #ifdef MSG_EOR
-	{ MSG_EOR,	"MSG_EOR"	},
+	{ MSG_EOR,		"MSG_EOR"		},
 #endif
 #ifdef MSG_WAITALL
-	{ MSG_WAITALL,	"MSG_WAITALL"	},
+	{ MSG_WAITALL,		"MSG_WAITALL"		},
 #endif
 #ifdef MSG_TRUNC
-	{ MSG_TRUNC,	"MSG_TRUNC"	},
+	{ MSG_TRUNC,		"MSG_TRUNC"		},
 #endif
 #ifdef MSG_CTRUNC
-	{ MSG_CTRUNC,	"MSG_CTRUNC"	},
+	{ MSG_CTRUNC,		"MSG_CTRUNC"		},
 #endif
 #ifdef MSG_ERRQUEUE
-	{ MSG_ERRQUEUE,	"MSG_ERRQUEUE"	},
+	{ MSG_ERRQUEUE,		"MSG_ERRQUEUE"		},
 #endif
 #ifdef MSG_DONTWAIT
-	{ MSG_DONTWAIT,	"MSG_DONTWAIT"	},
+	{ MSG_DONTWAIT,		"MSG_DONTWAIT"		},
 #endif
 #ifdef MSG_CONFIRM
-	{ MSG_CONFIRM,	"MSG_CONFIRM"	},
+	{ MSG_CONFIRM,		"MSG_CONFIRM"		},
 #endif
 #ifdef MSG_PROBE
-	{ MSG_PROBE,	"MSG_PROBE"	},
+	{ MSG_PROBE,		"MSG_PROBE"		},
 #endif
 #ifdef MSG_FIN
-	{ MSG_FIN,	"MSG_FIN"	},
+	{ MSG_FIN,		"MSG_FIN"		},
 #endif
 #ifdef MSG_SYN
-	{ MSG_SYN,	"MSG_SYN"	},
+	{ MSG_SYN,		"MSG_SYN"		},
 #endif
 #ifdef MSG_RST
-	{ MSG_RST,	"MSG_RST"	},
+	{ MSG_RST,		"MSG_RST"		},
 #endif
 #ifdef MSG_NOSIGNAL
-	{ MSG_NOSIGNAL,	"MSG_NOSIGNAL"	},
+	{ MSG_NOSIGNAL,		"MSG_NOSIGNAL"		},
 #endif
 #ifdef MSG_MORE
-	{ MSG_MORE,	"MSG_MORE"	},
+	{ MSG_MORE,		"MSG_MORE"		},
 #endif
-	{ 0,		NULL		},
+#ifdef MSG_CMSG_CLOEXEC
+	{ MSG_CMSG_CLOEXEC,	"MSG_CMSG_CLOEXEC"	},
+#endif
+	{ 0,			NULL			},
 };
 
 static const struct xlat sockoptions[] = {
@@ -800,8 +818,12 @@ static const struct xlat sockrawoptions[] = {
 
 #ifdef SOL_PACKET
 static const struct xlat sockpacketoptions[] = {
+#ifdef PACKET_ADD_MEMBERSHIP
 	{ PACKET_ADD_MEMBERSHIP,	"PACKET_ADD_MEMBERSHIP"	},
+#endif
+#ifdef PACKET_DROP_MEMBERSHIP
 	{ PACKET_DROP_MEMBERSHIP,	"PACKET_DROP_MEMBERSHIP"},
+#endif
 #if defined(PACKET_RECV_OUTPUT)
 	{ PACKET_RECV_OUTPUT,		"PACKET_RECV_OUTPUT"	},
 #endif
@@ -934,10 +956,7 @@ static const struct xlat af_packet_types[] = {
 
 
 void
-printsock(tcp, addr, addrlen)
-struct tcb *tcp;
-long addr;
-int addrlen;
+printsock(struct tcb *tcp, long addr, int addrlen)
 {
 	union {
 		char pad[128];
@@ -967,13 +986,16 @@ int addrlen;
 		tprintf("%#lx", addr);
 		return;
 	}
-	if ((addrlen<2) || (addrlen>sizeof(addrbuf)))
-		addrlen=sizeof(addrbuf);
 
-	if (umoven(tcp, addr, addrlen, (char*)&addrbuf) < 0) {
+	if (addrlen < 2 || addrlen > sizeof(addrbuf))
+		addrlen = sizeof(addrbuf);
+
+	memset(&addrbuf, 0, sizeof(addrbuf));
+	if (umoven(tcp, addr, addrlen, addrbuf.pad) < 0) {
 		tprintf("{...}");
 		return;
 	}
+	addrbuf.pad[sizeof(addrbuf.pad) - 1] = '\0';
 
 	tprintf("{sa_family=");
 	printxval(addrfams, addrbuf.sa.sa_family, "AF_???");
@@ -981,12 +1003,14 @@ int addrlen;
 
 	switch (addrbuf.sa.sa_family) {
 	case AF_UNIX:
-		if (addrlen==2) {
-			tprintf("<nil>");
+		if (addrlen == 2) {
+			tprintf("NULL");
 		} else if (addrbuf.sau.sun_path[0]) {
-			tprintf("path=\"%-.*s\"", addrlen-2, addrbuf.sau.sun_path);
+			tprintf("path=");
+			printpathn(tcp, addr + 2, strlen(addrbuf.sau.sun_path));
 		} else {
-			tprintf("path=@%-.*s", addrlen-3, addrbuf.sau.sun_path+1);
+			tprintf("path=@");
+			printpathn(tcp, addr + 3, strlen(addrbuf.sau.sun_path + 1));
 		}
 		break;
 	case AF_INET:
@@ -1086,10 +1110,7 @@ static const struct xlat scmvals[] = {
 };
 
 static void
-printcmsghdr(tcp, addr, len)
-struct tcb *tcp;
-unsigned long addr;
-unsigned long len;
+printcmsghdr(struct tcb *tcp, unsigned long addr, unsigned long len)
 {
 	struct cmsghdr *cmsg = len < sizeof(struct cmsghdr) ?
 			       NULL : malloc(len);
@@ -1099,7 +1120,7 @@ unsigned long len;
 		return;
 	}
 
-	tprintf(", {cmsg_len=%zu, cmsg_level=", cmsg->cmsg_len);
+	tprintf(", {cmsg_len=%u, cmsg_level=", (unsigned) cmsg->cmsg_len);
 	printxval(socketlayers, cmsg->cmsg_level, "SOL_???");
 	tprintf(", cmsg_type=");
 
@@ -1173,14 +1194,33 @@ long addr;
 
 #endif /* HAVE_SENDMSG */
 
+/*
+ * low bits of the socket type define real socket type,
+ * other bits are socket type flags.
+ */
+static void
+tprint_sock_type(struct tcb *tcp, int flags)
+{
+	const char *str = xlookup(socktypes, flags & SOCK_TYPE_MASK);
+
+	if (str)
+	{
+		tprintf("%s", str);
+		flags &= ~SOCK_TYPE_MASK;
+		if (!flags)
+			return;
+		tprintf("|");
+	}
+	printflags(sock_type_flags, flags, "SOCK_???");
+}
+
 int
-sys_socket(tcp)
-struct tcb *tcp;
+sys_socket(struct tcb *tcp)
 {
 	if (entering(tcp)) {
 		printxval(domains, tcp->u_arg[0], "PF_???");
 		tprintf(", ");
-		printxval(socktypes, tcp->u_arg[1], "SOCK_???");
+		tprint_sock_type(tcp, tcp->u_arg[1]);
 		tprintf(", ");
 		switch (tcp->u_arg[0]) {
 		case PF_INET:
@@ -1205,6 +1245,7 @@ struct tcb *tcp;
 	return 0;
 }
 
+#ifdef SVR4
 int
 sys_so_socket(tcp)
 struct tcb *tcp;
@@ -1226,11 +1267,12 @@ sys_so_socketpair(tcp)
 struct tcb *tcp;
 {
 	if (entering(tcp)) {
-	  	/* not sure what this arg is */
+		/* not sure what this arg is */
 		tprintf("0x%lx", tcp->u_arg[0]);
 	}
 	return 0;
 }
+#endif /* SVR4 */
 
 int
 sys_bind(tcp)
@@ -1261,26 +1303,48 @@ struct tcb *tcp;
 	return 0;
 }
 
-int
-sys_accept(tcp)
-struct tcb *tcp;
+static int
+do_accept(struct tcb *tcp, int flags_arg)
 {
 	if (entering(tcp)) {
 		tprintf("%ld, ", tcp->u_arg[0]);
-	} else if (!tcp->u_arg[2])
+		return 0;
+	}
+	if (!tcp->u_arg[2])
 		tprintf("%#lx, NULL", tcp->u_arg[1]);
 	else {
-		if (tcp->u_arg[1] == 0 || syserror(tcp)) {
+		int len;
+		if (tcp->u_arg[1] == 0 || syserror(tcp)
+		    || umove (tcp, tcp->u_arg[2], &len) < 0) {
 			tprintf("%#lx", tcp->u_arg[1]);
 		} else {
-			printsock(tcp, tcp->u_arg[1], tcp->u_arg[2]);
+			printsock(tcp, tcp->u_arg[1], len);
 		}
 		tprintf(", ");
-		printnum(tcp, tcp->u_arg[2], "%lu");
+		printnum_int(tcp, tcp->u_arg[2], "%u");
+	}
+	if (flags_arg >= 0) {
+		tprintf(", ");
+		printflags(sock_type_flags, tcp->u_arg[flags_arg],
+			   "SOCK_???");
 	}
 	return 0;
 }
 
+int
+sys_accept(struct tcb *tcp)
+{
+	return do_accept(tcp, -1);
+}
+
+#ifdef LINUX
+int
+sys_accept4(struct tcb *tcp)
+{
+	return do_accept(tcp, 3);
+}
+#endif
+
 int
 sys_send(tcp)
 struct tcb *tcp;
@@ -1452,34 +1516,50 @@ struct tcb *tcp;
 	return sys_accept(tcp);
 }
 
-int
-sys_pipe(tcp)
-struct tcb *tcp;
+static int
+do_pipe(struct tcb *tcp, int flags_arg)
 {
-
-#if defined(LINUX) && !defined(SPARC) && !defined(SPARC64) && !defined(SH) && !defined(IA64)
-	int fds[2];
-
 	if (exiting(tcp)) {
 		if (syserror(tcp)) {
 			tprintf("%#lx", tcp->u_arg[0]);
-			return 0;
-		}
-		if (umoven(tcp, tcp->u_arg[0], sizeof fds, (char *) fds) < 0)
-			tprintf("[...]");
-		else
-			tprintf("[%u, %u]", fds[0], fds[1]);
-	}
+		} else {
+#if defined(LINUX) && !defined(SPARC) && !defined(SPARC64) && !defined(SH) && !defined(IA64)
+			int fds[2];
+
+			if (umoven(tcp, tcp->u_arg[0], sizeof fds, (char *) fds) < 0)
+				tprintf("[...]");
+			else
+				tprintf("[%u, %u]", fds[0], fds[1]);
 #elif defined(SPARC) || defined(SPARC64) || defined(SH) || defined(SVR4) || defined(FREEBSD) || defined(IA64)
-	if (exiting(tcp))
-		tprintf("[%lu, %lu]", tcp->u_rval, getrval2(tcp));
+			tprintf("[%lu, %lu]", tcp->u_rval, getrval2(tcp));
+#else
+			tprintf("%#lx", tcp->u_arg[0]);
 #endif
+		}
+		if (flags_arg >= 0) {
+			tprintf(", ");
+			printflags(open_mode_flags, tcp->u_arg[flags_arg], "O_???");
+		}
+	}
 	return 0;
 }
 
 int
-sys_socketpair(tcp)
-struct tcb *tcp;
+sys_pipe(struct tcb *tcp)
+{
+	return do_pipe(tcp, -1);
+}
+
+#ifdef LINUX
+int
+sys_pipe2(struct tcb *tcp)
+{
+	return do_pipe(tcp, 1);
+}
+#endif
+
+int
+sys_socketpair(struct tcb *tcp)
 {
 #ifdef LINUX
 	int fds[2];
@@ -1488,7 +1568,7 @@ struct tcb *tcp;
 	if (entering(tcp)) {
 		printxval(domains, tcp->u_arg[0], "PF_???");
 		tprintf(", ");
-		printxval(socktypes, tcp->u_arg[1], "SOCK_???");
+		tprint_sock_type(tcp, tcp->u_arg[1]);
 		tprintf(", ");
 		switch (tcp->u_arg[0]) {
 		case PF_INET:
@@ -1581,7 +1661,7 @@ struct tcb *tcp;
 			switch (tcp->u_arg[2]) {
 #ifdef SO_LINGER
 			case SO_LINGER:
-			        if (len == sizeof (struct linger)) {
+				if (len == sizeof (struct linger)) {
 					struct linger linger;
 					if (umove (tcp,
 						   tcp->u_arg[3],
