@@ -24,7 +24,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: term.c,v 1.7 2004/09/04 03:39:20 roland Exp $
+ *	$Id$
  */
 
 #include "defs.h"
@@ -337,11 +337,10 @@ long code, arg;
 	case TIOCMBIS:
 	case TIOCMBIC:
 	case TIOCMSET:
-		if (umove(tcp, arg, &arg) < 0)
+		if (umove(tcp, arg, &i) < 0)
 			return 0;
 		tprintf(", [");
-		if (!printflags(modem_flags, arg))
-			tprintf("0");
+		printflags(modem_flags, i, "TIOCM_???");
 		tprintf("]");
 		return 1;
 #endif /* TIOCMGET */
@@ -415,7 +414,7 @@ long code, arg;
 	case TIOCGPTN:
 #endif
 		tprintf(", ");
-		printnum(tcp, arg, "%d");
+		printnum_int(tcp, arg, "%d");
 		return 1;
 
 #if 0
